/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWallet.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KWALLETADAPTOR_H
#define KWALLETADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kwalletd.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.kde.KWallet
 */
class KWalletAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.kde.KWallet")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.kde.KWallet\">\n"
"    <signal name=\"walletListDirty\"/>\n"
"    <signal name=\"walletCreated\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"wallet\"/>\n"
"    </signal>\n"
"    <signal name=\"walletOpened\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"wallet\"/>\n"
"    </signal>\n"
"    <signal name=\"walletAsyncOpened\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"tId\"/>\n"
"      <arg direction=\"out\" type=\"i\" name=\"handle\"/>\n"
"    </signal>\n"
"    <signal name=\"walletDeleted\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"wallet\"/>\n"
"    </signal>\n"
"    <signal name=\"walletClosed\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"wallet\"/>\n"
"    </signal>\n"
"    <signal name=\"walletClosed\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"handle\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Deprecated\"/>\n"
"    </signal>\n"
"    <signal name=\"walletClosedId\">\n"
"      <arg direction=\"out\" type=\"i\" name=\"handle\"/>\n"
"    </signal>\n"
"    <signal name=\"allWalletsClosed\"/>\n"
"    <signal name=\"folderListUpdated\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"wallet\"/>\n"
"    </signal>\n"
"    <signal name=\"folderUpdated\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </signal>\n"
"    <signal name=\"applicationDisconnected\">\n"
"      <arg direction=\"out\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"out\" type=\"s\" name=\"application\"/>\n"
"    </signal>\n"
"    <method name=\"isEnabled\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"    </method>\n"
"    <method name=\"open\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"wId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"openPath\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"wId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"openAsync\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"wId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"handleSession\"/>\n"
"    </method>\n"
"    <method name=\"openPathAsync\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"path\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"wId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"handleSession\"/>\n"
"    </method>\n"
"    <method name=\"close\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"force\"/>\n"
"    </method>\n"
"    <method name=\"close\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"force\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"sync\">\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"    <method name=\"deleteWallet\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"    </method>\n"
"    <method name=\"isOpen\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"    </method>\n"
"    <method name=\"isOpen\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"    </method>\n"
"    <method name=\"users\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"    </method>\n"
"    <method name=\"changePassword\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"x\" name=\"wId\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"wallets\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"    </method>\n"
"    <method name=\"folderList\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"hasFolder\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"createFolder\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"removeFolder\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"entryList\">\n"
"      <arg direction=\"out\" type=\"as\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"readEntry\">\n"
"      <arg direction=\"out\" type=\"ay\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"readMap\">\n"
"      <arg direction=\"out\" type=\"ay\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"readPassword\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"readEntryList\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Deprecated\"/>\n"
"    </method>\n"
"    <method name=\"entriesList\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"readMapList\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Deprecated\"/>\n"
"    </method>\n"
"    <method name=\"mapList\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"readPasswordList\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Deprecated\"/>\n"
"    </method>\n"
"    <method name=\"passwordList\">\n"
"      <arg direction=\"out\" type=\"a{sv}\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"renameEntry\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"oldName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"newName\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"writeEntry\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"ay\" name=\"value\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"entryType\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"writeEntry\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"ay\" name=\"value\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"writeMap\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"ay\" name=\"value\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"writePassword\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"value\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"hasEntry\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"entryType\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"removeEntry\">\n"
"      <arg direction=\"out\" type=\"i\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n"
"    </method>\n"
"    <method name=\"disconnectApplication\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"application\"/>\n"
"    </method>\n"
"    <method name=\"reconfigure\"/>\n"
"    <method name=\"folderDoesNotExist\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"    </method>\n"
"    <method name=\"keyDoesNotExist\">\n"
"      <arg direction=\"out\" type=\"b\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n"
"    </method>\n"
"    <method name=\"closeAllWallets\"/>\n"
"    <method name=\"networkWallet\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"localWallet\">\n"
"      <arg direction=\"out\" type=\"s\"/>\n"
"    </method>\n"
"    <method name=\"pamOpen\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n"
"      <arg direction=\"in\" type=\"ay\" name=\"passwordHash\"/>\n"
"      <arg direction=\"in\" type=\"i\" name=\"sessionTimeout\"/>\n"
"      <annotation value=\"true\" name=\"org.freedesktop.DBus.Method.NoReply\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    KWalletAdaptor(KWalletD *parent);
    ~KWalletAdaptor() override;

    inline KWalletD *parent() const
    { return static_cast<KWalletD *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void changePassword(const QString &wallet, qlonglong wId, const QString &appid);
    int close(int handle, bool force, const QString &appid);
    int close(const QString &wallet, bool force);
    void closeAllWallets();
    bool createFolder(int handle, const QString &folder, const QString &appid);
    int deleteWallet(const QString &wallet);
    bool disconnectApplication(const QString &wallet, const QString &application);
    QVariantMap entriesList(int handle, const QString &folder, const QString &appid);
    QStringList entryList(int handle, const QString &folder, const QString &appid);
    int entryType(int handle, const QString &folder, const QString &key, const QString &appid);
    bool folderDoesNotExist(const QString &wallet, const QString &folder);
    QStringList folderList(int handle, const QString &appid);
    bool hasEntry(int handle, const QString &folder, const QString &key, const QString &appid);
    bool hasFolder(int handle, const QString &folder, const QString &appid);
    bool isEnabled();
    bool isOpen(int handle);
    bool isOpen(const QString &wallet);
    bool keyDoesNotExist(const QString &wallet, const QString &folder, const QString &key);
    QString localWallet();
    QVariantMap mapList(int handle, const QString &folder, const QString &appid);
    QString networkWallet();
    int open(const QString &wallet, qlonglong wId, const QString &appid);
    int openAsync(const QString &wallet, qlonglong wId, const QString &appid, bool handleSession);
    int openPath(const QString &path, qlonglong wId, const QString &appid);
    int openPathAsync(const QString &path, qlonglong wId, const QString &appid, bool handleSession);
    Q_NOREPLY void pamOpen(const QString &wallet, const QByteArray &passwordHash, int sessionTimeout);
    QVariantMap passwordList(int handle, const QString &folder, const QString &appid);
    QByteArray readEntry(int handle, const QString &folder, const QString &key, const QString &appid);
    QVariantMap readEntryList(int handle, const QString &folder, const QString &key, const QString &appid);
    QByteArray readMap(int handle, const QString &folder, const QString &key, const QString &appid);
    QVariantMap readMapList(int handle, const QString &folder, const QString &key, const QString &appid);
    QString readPassword(int handle, const QString &folder, const QString &key, const QString &appid);
    QVariantMap readPasswordList(int handle, const QString &folder, const QString &key, const QString &appid);
    void reconfigure();
    int removeEntry(int handle, const QString &folder, const QString &key, const QString &appid);
    bool removeFolder(int handle, const QString &folder, const QString &appid);
    int renameEntry(int handle, const QString &folder, const QString &oldName, const QString &newName, const QString &appid);
    Q_NOREPLY void sync(int handle, const QString &appid);
    QStringList users(const QString &wallet);
    QStringList wallets();
    int writeEntry(int handle, const QString &folder, const QString &key, const QByteArray &value, const QString &appid);
    int writeEntry(int handle, const QString &folder, const QString &key, const QByteArray &value, int entryType, const QString &appid);
    int writeMap(int handle, const QString &folder, const QString &key, const QByteArray &value, const QString &appid);
    int writePassword(int handle, const QString &folder, const QString &key, const QString &value, const QString &appid);
Q_SIGNALS: // SIGNALS
    void allWalletsClosed();
    void applicationDisconnected(const QString &wallet, const QString &application);
    void folderListUpdated(const QString &wallet);
    void folderUpdated(const QString &in0, const QString &in1);
    void walletAsyncOpened(int tId, int handle);
    void walletClosed(int handle);
    void walletClosed(const QString &wallet);
    void walletClosedId(int handle);
    void walletCreated(const QString &wallet);
    void walletDeleted(const QString &wallet);
    void walletListDirty();
    void walletOpened(const QString &wallet);
};

#endif
