/****************************************************************************
** Meta object code from reading C++ file 'kwalletfreedesktopservice.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kwallet-6.25.0/src/runtime/ksecretd/kwalletfreedesktopservice.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletfreedesktopservice.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25KWalletFreedesktopServiceE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletFreedesktopService::qt_create_metaobjectdata<qt_meta_tag_ZN25KWalletFreedesktopServiceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletFreedesktopService",
        "CollectionChanged",
        "",
        "QDBusObjectPath",
        "collection",
        "CollectionCreated",
        "CollectionDeleted",
        "lockCollection",
        "name",
        "entryUpdated",
        "walletName",
        "folder",
        "entryName",
        "entryDeleted",
        "entryRenamed",
        "oldName",
        "newName",
        "walletDeleted",
        "walletCreated",
        "CreateCollection",
        "QVariantMap",
        "properties",
        "alias",
        "QDBusObjectPath&",
        "prompt",
        "GetSecrets",
        "FreedesktopSecretMap",
        "QList<QDBusObjectPath>",
        "items",
        "session",
        "Lock",
        "objects",
        "Prompt",
        "OpenSession",
        "QDBusVariant",
        "algorithm",
        "input",
        "result",
        "ReadAlias",
        "SearchItems",
        "StrStrMap",
        "attributes",
        "QList<QDBusObjectPath>&",
        "locked",
        "SetAlias",
        "Unlock",
        "Collections"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CollectionChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'CollectionCreated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'CollectionDeleted'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'lockCollection'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'entryUpdated'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'entryDeleted'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 12 },
        }}),
        // Slot 'entryRenamed'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &, const QString &)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'walletDeleted'
        QtMocHelpers::SlotData<void(const QString &)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 10 },
        }}),
        // Slot 'walletCreated'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Slot 'CreateCollection'
        QtMocHelpers::SlotData<QDBusObjectPath(const QVariantMap &, const QString &, QDBusObjectPath &)>(19, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 20, 21 }, { QMetaType::QString, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'GetSecrets'
        QtMocHelpers::SlotData<FreedesktopSecretMap(const QList<QDBusObjectPath> &, const QDBusObjectPath &)>(25, 2, QMC::AccessPublic, 0x80000000 | 26, {{
            { 0x80000000 | 27, 28 }, { 0x80000000 | 3, 29 },
        }}),
        // Slot 'Lock'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>(const QList<QDBusObjectPath> &, QDBusObjectPath &)>(30, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 27, 31 }, { 0x80000000 | 23, 32 },
        }}),
        // Slot 'OpenSession'
        QtMocHelpers::SlotData<QDBusVariant(const QString &, const QDBusVariant &, QDBusObjectPath &)>(33, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::QString, 35 }, { 0x80000000 | 34, 36 }, { 0x80000000 | 23, 37 },
        }}),
        // Slot 'ReadAlias'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &)>(38, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'SearchItems'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>(const StrStrMap &, QList<QDBusObjectPath> &)>(39, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 40, 41 }, { 0x80000000 | 42, 43 },
        }}),
        // Slot 'SetAlias'
        QtMocHelpers::SlotData<void(const QString &, const QDBusObjectPath &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { 0x80000000 | 3, 4 },
        }}),
        // Slot 'Unlock'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>(const QList<QDBusObjectPath> &, QDBusObjectPath &)>(45, 2, QMC::AccessPublic, 0x80000000 | 27, {{
            { 0x80000000 | 27, 31 }, { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Collections'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(46, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KWalletFreedesktopService, qt_meta_tag_ZN25KWalletFreedesktopServiceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWalletFreedesktopService::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KWalletFreedesktopServiceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KWalletFreedesktopServiceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25KWalletFreedesktopServiceE_t>.metaTypes,
    nullptr
} };

void KWalletFreedesktopService::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletFreedesktopService *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CollectionChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 1: _t->CollectionCreated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: _t->CollectionDeleted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 3: _t->lockCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->entryUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->entryDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->entryRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 7: _t->walletDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->walletCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { QDBusObjectPath _r = _t->CreateCollection((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 10: { FreedesktopSecretMap _r = _t->GetSecrets((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<FreedesktopSecretMap*>(_a[0]) = std::move(_r); }  break;
        case 11: { QList<QDBusObjectPath> _r = _t->Lock((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 12: { QDBusVariant _r = _t->OpenSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusObjectPath _r = _t->ReadAlias((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 14: { QList<QDBusObjectPath> _r = _t->SearchItems((*reinterpret_cast<std::add_pointer_t<StrStrMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->SetAlias((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 16: { QList<QDBusObjectPath> _r = _t->Unlock((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StrStrMap >(); break;
            }
            break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QDBusObjectPath> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopService::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopService::CollectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopService::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopService::CollectionCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopService::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopService::CollectionDeleted, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->collections(); break;
        default: break;
        }
    }
}

const QMetaObject *KWalletFreedesktopService::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletFreedesktopService::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25KWalletFreedesktopServiceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int KWalletFreedesktopService::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KWalletFreedesktopService::CollectionChanged(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KWalletFreedesktopService::CollectionCreated(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KWalletFreedesktopService::CollectionDeleted(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
