/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Secrets.Service.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KWALLETFREEDESKTOPSERVICEADAPTOR_H
#define KWALLETFREEDESKTOPSERVICEADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kwalletfreedesktopservice.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Secret.Service
 */
class KWalletFreedesktopServiceAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Secret.Service")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Secret.Service\">\n"
"    <property access=\"read\" type=\"ao\" name=\"Collections\"/>\n"
"    <method name=\"OpenSession\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"algorithm\"/>\n"
"      <arg direction=\"in\" type=\"v\" name=\"input\"/>\n"
"      <arg direction=\"out\" type=\"v\" name=\"output\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"result\"/>\n"
"    </method>\n"
"    <method name=\"CreateCollection\">\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"properties\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"alias\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"collection\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"prompt\"/>\n"
"    </method>\n"
"    <method name=\"SearchItems\">\n"
"      <arg direction=\"in\" type=\"a{ss}\" name=\"attributes\"/>\n"
"      <annotation value=\"StrStrMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"out\" type=\"ao\" name=\"unlocked\"/>\n"
"      <arg direction=\"out\" type=\"ao\" name=\"locked\"/>\n"
"    </method>\n"
"    <method name=\"Unlock\">\n"
"      <arg direction=\"in\" type=\"ao\" name=\"objects\"/>\n"
"      <arg direction=\"out\" type=\"ao\" name=\"unlocked\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"prompt\"/>\n"
"    </method>\n"
"    <method name=\"Lock\">\n"
"      <arg direction=\"in\" type=\"ao\" name=\"objects\"/>\n"
"      <arg direction=\"out\" type=\"ao\" name=\"locked\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"Prompt\"/>\n"
"    </method>\n"
"    <method name=\"GetSecrets\">\n"
"      <arg direction=\"in\" type=\"ao\" name=\"items\"/>\n"
"      <arg direction=\"in\" type=\"o\" name=\"session\"/>\n"
"      <arg direction=\"out\" type=\"a{o(oayays)}\" name=\"secrets\"/>\n"
"      <annotation value=\"FreedesktopSecretMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n"
"    </method>\n"
"    <method name=\"ReadAlias\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"collection\"/>\n"
"    </method>\n"
"    <method name=\"SetAlias\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"name\"/>\n"
"      <arg direction=\"in\" type=\"o\" name=\"collection\"/>\n"
"    </method>\n"
"    <signal name=\"CollectionCreated\">\n"
"      <arg type=\"o\" name=\"collection\"/>\n"
"    </signal>\n"
"    <signal name=\"CollectionDeleted\">\n"
"      <arg type=\"o\" name=\"collection\"/>\n"
"    </signal>\n"
"    <signal name=\"CollectionChanged\">\n"
"      <arg type=\"o\" name=\"collection\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    KWalletFreedesktopServiceAdaptor(KWalletFreedesktopService *parent);
    ~KWalletFreedesktopServiceAdaptor() override;

    inline KWalletFreedesktopService *parent() const
    { return static_cast<KWalletFreedesktopService *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QList<QDBusObjectPath> Collections READ collections)
    QList<QDBusObjectPath> collections() const;

public Q_SLOTS: // METHODS
    QDBusObjectPath CreateCollection(const QVariantMap &properties, const QString &alias, QDBusObjectPath &prompt);
    FreedesktopSecretMap GetSecrets(const QList<QDBusObjectPath> &items, const QDBusObjectPath &session);
    QList<QDBusObjectPath> Lock(const QList<QDBusObjectPath> &objects, QDBusObjectPath &Prompt);
    QDBusVariant OpenSession(const QString &algorithm, const QDBusVariant &input, QDBusObjectPath &result);
    QDBusObjectPath ReadAlias(const QString &name);
    QList<QDBusObjectPath> SearchItems(StrStrMap attributes, QList<QDBusObjectPath> &locked);
    void SetAlias(const QString &name, const QDBusObjectPath &collection);
    QList<QDBusObjectPath> Unlock(const QList<QDBusObjectPath> &objects, QDBusObjectPath &prompt);
Q_SIGNALS: // SIGNALS
    void CollectionChanged(const QDBusObjectPath &collection);
    void CollectionCreated(const QDBusObjectPath &collection);
    void CollectionDeleted(const QDBusObjectPath &collection);
};

#endif
