/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.impl.portal.Secret.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KWALLETPORTALSECRETSADAPTOR_H
#define KWALLETPORTALSECRETSADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kwalletportalsecrets.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.impl.portal.Secret
 */
class KWalletPortalSecretsAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.impl.portal.Secret")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.impl.portal.Secret\">\n"
"    <method name=\"RetrieveSecret\">\n"
"      <annotation value=\"retrieve_secret\" name=\"org.gtk.GDBus.C.Name\"/>\n"
"      <annotation value=\"true\" name=\"org.gtk.GDBus.C.UnixFD\"/>\n"
"      <arg direction=\"in\" type=\"o\" name=\"handle\"/>\n"
"      <arg direction=\"in\" type=\"s\" name=\"app_id\"/>\n"
"      <arg direction=\"in\" type=\"h\" name=\"fd\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In3\"/>\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"options\"/>\n"
"      <arg direction=\"out\" type=\"u\" name=\"response\"/>\n"
"      <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out1\"/>\n"
"      <arg direction=\"out\" type=\"a{sv}\" name=\"results\"/>\n"
"    </method>\n"
"    <property access=\"read\" type=\"u\" name=\"version\"/>\n"
"  </interface>\n"
        "")
public:
    KWalletPortalSecretsAdaptor(KWalletPortalSecrets *parent);
    ~KWalletPortalSecretsAdaptor() override;

    inline KWalletPortalSecrets *parent() const
    { return static_cast<KWalletPortalSecrets *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(uint version READ version)
    uint version() const;

public Q_SLOTS: // METHODS
    uint RetrieveSecret(const QDBusObjectPath &handle, const QString &app_id, const QDBusUnixFileDescriptor &fd, const QVariantMap &options, QVariantMap &results);
Q_SIGNALS: // SIGNALS
};

#endif
