/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Secrets.Item.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kwalletfreedesktopitemadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KWalletFreedesktopItemAdaptor
 */

KWalletFreedesktopItemAdaptor::KWalletFreedesktopItemAdaptor(KWalletFreedesktopItem *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KWalletFreedesktopItemAdaptor::~KWalletFreedesktopItemAdaptor()
{
    // destructor
}

StrStrMap KWalletFreedesktopItemAdaptor::attributes() const
{
    // get the value of property Attributes
    return qvariant_cast< StrStrMap >(parent()->property("Attributes"));
}

void KWalletFreedesktopItemAdaptor::setAttributes(StrStrMap value)
{
    // set the value of property Attributes
    parent()->setProperty("Attributes", QVariant::fromValue(value));
}

qulonglong KWalletFreedesktopItemAdaptor::created() const
{
    // get the value of property Created
    return qvariant_cast< qulonglong >(parent()->property("Created"));
}

QString KWalletFreedesktopItemAdaptor::label() const
{
    // get the value of property Label
    return qvariant_cast< QString >(parent()->property("Label"));
}

void KWalletFreedesktopItemAdaptor::setLabel(const QString &value)
{
    // set the value of property Label
    parent()->setProperty("Label", QVariant::fromValue(value));
}

bool KWalletFreedesktopItemAdaptor::locked() const
{
    // get the value of property Locked
    return qvariant_cast< bool >(parent()->property("Locked"));
}

qulonglong KWalletFreedesktopItemAdaptor::modified() const
{
    // get the value of property Modified
    return qvariant_cast< qulonglong >(parent()->property("Modified"));
}

QString KWalletFreedesktopItemAdaptor::type() const
{
    // get the value of property Type
    return qvariant_cast< QString >(parent()->property("Type"));
}

void KWalletFreedesktopItemAdaptor::setType(const QString &value)
{
    // set the value of property Type
    parent()->setProperty("Type", QVariant::fromValue(value));
}

QDBusObjectPath KWalletFreedesktopItemAdaptor::Delete()
{
    // handle method call org.freedesktop.Secret.Item.Delete
    return parent()->Delete();
}

FreedesktopSecret KWalletFreedesktopItemAdaptor::GetSecret(const QDBusObjectPath &session)
{
    // handle method call org.freedesktop.Secret.Item.GetSecret
    return parent()->GetSecret(session);
}

void KWalletFreedesktopItemAdaptor::SetSecret(FreedesktopSecret secret)
{
    // handle method call org.freedesktop.Secret.Item.SetSecret
    parent()->SetSecret(secret);
}


#include "moc_kwalletfreedesktopitemadaptor.cpp"
