/****************************************************************************
** Meta object code from reading C++ file 'kwalletadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kwalletadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14KWalletAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN14KWalletAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletAdaptor",
        "D-Bus Interface",
        "org.kde.KWallet",
        "D-Bus Introspection",
        "  <interface name=\"org.kde.KWallet\">\n    <signal name=\"walletL"
        "istDirty\"/>\n    <signal name=\"walletCreated\">\n      <arg dire"
        "ction=\"out\" type=\"s\" name=\"wallet\"/>\n    </signal>\n    <si"
        "gnal name=\"walletOpened\">\n      <arg direction=\"out\" type=\"s"
        "\" name=\"wallet\"/>\n    </signal>\n    <signal name=\"walletAsyn"
        "cOpened\">\n      <arg direction=\"out\" type=\"i\" name=\"tId\"/>"
        "\n      <arg direction=\"out\" type=\"i\" name=\"handle\"/>\n    <"
        "/signal>\n    <signal name=\"walletDeleted\">\n      <arg directio"
        "n=\"out\" type=\"s\" name=\"wallet\"/>\n    </signal>\n    <signal"
        " name=\"walletClosed\">\n      <arg direction=\"out\" type=\"s\" n"
        "ame=\"wallet\"/>\n    </signal>\n    <signal name=\"walletClosed\""
        ">\n      <arg direction=\"out\" type=\"i\" name=\"handle\"/>\n    "
        "  <annotation value=\"true\" name=\"org.freedesktop.DBus.Deprecate"
        "d\"/>\n    </signal>\n    <signal name=\"walletClosedId\">\n      "
        "<arg direction=\"out\" type=\"i\" name=\"handle\"/>\n    </signal>"
        "\n    <signal name=\"allWalletsClosed\"/>\n    <signal name=\"fold"
        "erListUpdated\">\n      <arg direction=\"out\" type=\"s\" name=\"w"
        "allet\"/>\n    </signal>\n    <signal name=\"folderUpdated\">\n   "
        "   <arg direction=\"out\" type=\"s\"/>\n      <arg direction=\"out"
        "\" type=\"s\"/>\n    </signal>\n    <signal name=\"applicationDisc"
        "onnected\">\n      <arg direction=\"out\" type=\"s\" name=\"wallet"
        "\"/>\n      <arg direction=\"out\" type=\"s\" name=\"application\""
        "/>\n    </signal>\n    <method name=\"isEnabled\">\n      <arg dir"
        "ection=\"out\" type=\"b\"/>\n    </method>\n    <method name=\"ope"
        "n\">\n      <arg direction=\"out\" type=\"i\"/>\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"wallet\"/>\n      <arg direction=\"in"
        "\" type=\"x\" name=\"wId\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"appid\"/>\n    </method>\n    <method name=\"openPath\">"
        "\n      <arg direction=\"out\" type=\"i\"/>\n      <arg direction="
        "\"in\" type=\"s\" name=\"path\"/>\n      <arg direction=\"in\" typ"
        "e=\"x\" name=\"wId\"/>\n      <arg direction=\"in\" type=\"s\" nam"
        "e=\"appid\"/>\n    </method>\n    <method name=\"openAsync\">\n   "
        "   <arg direction=\"out\" type=\"i\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"wallet\"/>\n      <arg direction=\"in\" type=\""
        "x\" name=\"wId\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "appid\"/>\n      <arg direction=\"in\" type=\"b\" name=\"handleSes"
        "sion\"/>\n    </method>\n    <method name=\"openPathAsync\">\n    "
        "  <arg direction=\"out\" type=\"i\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"path\"/>\n      <arg direction=\"in\" type=\"x\""
        " name=\"wId\"/>\n      <arg direction=\"in\" type=\"s\" name=\"app"
        "id\"/>\n      <arg direction=\"in\" type=\"b\" name=\"handleSessio"
        "n\"/>\n    </method>\n    <method name=\"close\">\n      <arg dire"
        "ction=\"out\" type=\"i\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"wallet\"/>\n      <arg direction=\"in\" type=\"b\" name=\""
        "force\"/>\n    </method>\n    <method name=\"close\">\n      <arg "
        "direction=\"out\" type=\"i\"/>\n      <arg direction=\"in\" type=\""
        "i\" name=\"handle\"/>\n      <arg direction=\"in\" type=\"b\" name"
        "=\"force\"/>\n      <arg direction=\"in\" type=\"s\" name=\"appid\""
        "/>\n    </method>\n    <method name=\"sync\">\n      <arg directio"
        "n=\"in\" type=\"i\" name=\"handle\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"appid\"/>\n      <annotation value=\"true\" nam"
        "e=\"org.freedesktop.DBus.Method.NoReply\"/>\n    </method>\n    <m"
        "ethod name=\"deleteWallet\">\n      <arg direction=\"out\" type=\""
        "i\"/>\n      <arg direction=\"in\" type=\"s\" name=\"wallet\"/>\n "
        "   </method>\n    <method name=\"isOpen\">\n      <arg direction=\""
        "out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\""
        "wallet\"/>\n    </method>\n    <method name=\"isOpen\">\n      <ar"
        "g direction=\"out\" type=\"b\"/>\n      <arg direction=\"in\" type"
        "=\"i\" name=\"handle\"/>\n    </method>\n    <method name=\"users\""
        ">\n      <arg direction=\"out\" type=\"as\"/>\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"wallet\"/>\n    </method>\n    <method "
        "name=\"changePassword\">\n      <arg direction=\"in\" type=\"s\" n"
        "ame=\"wallet\"/>\n      <arg direction=\"in\" type=\"x\" name=\"wI"
        "d\"/>\n      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n  "
        "  </method>\n    <method name=\"wallets\">\n      <arg direction=\""
        "out\" type=\"as\"/>\n    </method>\n    <method name=\"folderList\""
        ">\n      <arg direction=\"out\" type=\"as\"/>\n      <arg directio"
        "n=\"in\" type=\"i\" name=\"handle\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"appid\"/>\n    </method>\n    <method name=\"ha"
        "sFolder\">\n      <arg direction=\"out\" type=\"b\"/>\n      <arg "
        "direction=\"in\" type=\"i\" name=\"handle\"/>\n      <arg directio"
        "n=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"appid\"/>\n    </method>\n    <method name=\"cr"
        "eateFolder\">\n      <arg direction=\"out\" type=\"b\"/>\n      <a"
        "rg direction=\"in\" type=\"i\" name=\"handle\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"appid\"/>\n    </method>\n    <method name=\""
        "removeFolder\">\n      <arg direction=\"out\" type=\"b\"/>\n      "
        "<arg direction=\"in\" type=\"i\" name=\"handle\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"appid\"/>\n    </method>\n    <method name="
        "\"entryList\">\n      <arg direction=\"out\" type=\"as\"/>\n      "
        "<arg direction=\"in\" type=\"i\" name=\"handle\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"appid\"/>\n    </method>\n    <method name="
        "\"readEntry\">\n      <arg direction=\"out\" type=\"ay\"/>\n      "
        "<arg direction=\"in\" type=\"i\" name=\"handle\"/>\n      <arg dir"
        "ection=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direction=\""
        "in\" type=\"s\" name=\"key\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"appid\"/>\n    </method>\n    <method name=\"readMap\">"
        "\n      <arg direction=\"out\" type=\"ay\"/>\n      <arg direction"
        "=\"in\" type=\"i\" name=\"handle\"/>\n      <arg direction=\"in\" "
        "type=\"s\" name=\"folder\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"key\"/>\n      <arg direction=\"in\" type=\"s\" name=\"a"
        "ppid\"/>\n    </method>\n    <method name=\"readPassword\">\n     "
        " <arg direction=\"out\" type=\"s\"/>\n      <arg direction=\"in\" "
        "type=\"i\" name=\"handle\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"folder\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"key\"/>\n      <arg direction=\"in\" type=\"s\" name=\"appid\"/>"
        "\n    </method>\n    <method name=\"readEntryList\">\n      <arg d"
        "irection=\"out\" type=\"a{sv}\"/>\n      <annotation value=\"QVari"
        "antMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <a"
        "rg direction=\"in\" type=\"i\" name=\"handle\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"key\"/>\n      <arg direction=\"in\" type=\""
        "s\" name=\"appid\"/>\n      <annotation value=\"true\" name=\"org."
        "freedesktop.DBus.Deprecated\"/>\n    </method>\n    <method name=\""
        "entriesList\">\n      <arg direction=\"out\" type=\"a{sv}\"/>\n   "
        "   <annotation value=\"QVariantMap\" name=\"org.qtproject.QtDBus.Q"
        "tTypeName.Out0\"/>\n      <arg direction=\"in\" type=\"i\" name=\""
        "handle\"/>\n      <arg direction=\"in\" type=\"s\" name=\"folder\""
        "/>\n      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n    <"
        "/method>\n    <method name=\"readMapList\">\n      <arg direction="
        "\"out\" type=\"a{sv}\"/>\n      <annotation value=\"QVariantMap\" "
        "name=\"org.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <arg direct"
        "ion=\"in\" type=\"i\" name=\"handle\"/>\n      <arg direction=\"in"
        "\" type=\"s\" name=\"folder\"/>\n      <arg direction=\"in\" type="
        "\"s\" name=\"key\"/>\n      <arg direction=\"in\" type=\"s\" name="
        "\"appid\"/>\n      <annotation value=\"true\" name=\"org.freedeskt"
        "op.DBus.Deprecated\"/>\n    </method>\n    <method name=\"mapList\""
        ">\n      <arg direction=\"out\" type=\"a{sv}\"/>\n      <annotatio"
        "n value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out"
        "0\"/>\n      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n "
        "     <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n      <ar"
        "g direction=\"in\" type=\"s\" name=\"appid\"/>\n    </method>\n   "
        " <method name=\"readPasswordList\">\n      <arg direction=\"out\" "
        "type=\"a{sv}\"/>\n      <annotation value=\"QVariantMap\" name=\"o"
        "rg.qtproject.QtDBus.QtTypeName.Out0\"/>\n      <arg direction=\"in"
        "\" type=\"i\" name=\"handle\"/>\n      <arg direction=\"in\" type="
        "\"s\" name=\"folder\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"key\"/>\n      <arg direction=\"in\" type=\"s\" name=\"appid\""
        "/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBus.D"
        "eprecated\"/>\n    </method>\n    <method name=\"passwordList\">\n"
        "      <arg direction=\"out\" type=\"a{sv}\"/>\n      <annotation v"
        "alue=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.Out0\""
        "/>\n      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n    "
        "  <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"appid\"/>\n    </method>\n    <m"
        "ethod name=\"renameEntry\">\n      <arg direction=\"out\" type=\"i"
        "\"/>\n      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n  "
        "    <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n      <arg"
        " direction=\"in\" type=\"s\" name=\"oldName\"/>\n      <arg direct"
        "ion=\"in\" type=\"s\" name=\"newName\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"appid\"/>\n    </method>\n    <method name=\""
        "writeEntry\">\n      <arg direction=\"out\" type=\"i\"/>\n      <a"
        "rg direction=\"in\" type=\"i\" name=\"handle\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direction=\"i"
        "n\" type=\"s\" name=\"key\"/>\n      <arg direction=\"in\" type=\""
        "ay\" name=\"value\"/>\n      <arg direction=\"in\" type=\"i\" name"
        "=\"entryType\"/>\n      <arg direction=\"in\" type=\"s\" name=\"ap"
        "pid\"/>\n    </method>\n    <method name=\"writeEntry\">\n      <a"
        "rg direction=\"out\" type=\"i\"/>\n      <arg direction=\"in\" typ"
        "e=\"i\" name=\"handle\"/>\n      <arg direction=\"in\" type=\"s\" "
        "name=\"folder\"/>\n      <arg direction=\"in\" type=\"s\" name=\"k"
        "ey\"/>\n      <arg direction=\"in\" type=\"ay\" name=\"value\"/>\n"
        "      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n    </met"
        "hod>\n    <method name=\"writeMap\">\n      <arg direction=\"out\""
        " type=\"i\"/>\n      <arg direction=\"in\" type=\"i\" name=\"handl"
        "e\"/>\n      <arg direction=\"in\" type=\"s\" name=\"folder\"/>\n "
        "     <arg direction=\"in\" type=\"s\" name=\"key\"/>\n      <arg d"
        "irection=\"in\" type=\"ay\" name=\"value\"/>\n      <arg direction"
        "=\"in\" type=\"s\" name=\"appid\"/>\n    </method>\n    <method na"
        "me=\"writePassword\">\n      <arg direction=\"out\" type=\"i\"/>\n"
        "      <arg direction=\"in\" type=\"i\" name=\"handle\"/>\n      <a"
        "rg direction=\"in\" type=\"s\" name=\"folder\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"key\"/>\n      <arg direction=\"in\""
        " type=\"s\" name=\"value\"/>\n      <arg direction=\"in\" type=\"s"
        "\" name=\"appid\"/>\n    </method>\n    <method name=\"hasEntry\">"
        "\n      <arg direction=\"out\" type=\"b\"/>\n      <arg direction="
        "\"in\" type=\"i\" name=\"handle\"/>\n      <arg direction=\"in\" t"
        "ype=\"s\" name=\"folder\"/>\n      <arg direction=\"in\" type=\"s\""
        " name=\"key\"/>\n      <arg direction=\"in\" type=\"s\" name=\"app"
        "id\"/>\n    </method>\n    <method name=\"entryType\">\n      <arg"
        " direction=\"out\" type=\"i\"/>\n      <arg direction=\"in\" type="
        "\"i\" name=\"handle\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"folder\"/>\n      <arg direction=\"in\" type=\"s\" name=\"key"
        "\"/>\n      <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n   "
        " </method>\n    <method name=\"removeEntry\">\n      <arg directio"
        "n=\"out\" type=\"i\"/>\n      <arg direction=\"in\" type=\"i\" nam"
        "e=\"handle\"/>\n      <arg direction=\"in\" type=\"s\" name=\"fold"
        "er\"/>\n      <arg direction=\"in\" type=\"s\" name=\"key\"/>\n   "
        "   <arg direction=\"in\" type=\"s\" name=\"appid\"/>\n    </method"
        ">\n    <method name=\"disconnectApplication\">\n      <arg directi"
        "on=\"out\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"wallet\"/>\n      <arg direction=\"in\" type=\"s\" name=\"app"
        "lication\"/>\n    </method>\n    <method name=\"reconfigure\"/>\n "
        "   <method name=\"folderDoesNotExist\">\n      <arg direction=\"ou"
        "t\" type=\"b\"/>\n      <arg direction=\"in\" type=\"s\" name=\"wa"
        "llet\"/>\n      <arg direction=\"in\" type=\"s\" name=\"folder\"/>"
        "\n    </method>\n    <method name=\"keyDoesNotExist\">\n      <arg"
        " direction=\"out\" type=\"b\"/>\n      <arg direction=\"in\" type="
        "\"s\" name=\"wallet\"/>\n      <arg direction=\"in\" type=\"s\" na"
        "me=\"folder\"/>\n      <arg direction=\"in\" type=\"s\" name=\"key"
        "\"/>\n    </method>\n    <method name=\"closeAllWallets\"/>\n    <"
        "method name=\"networkWallet\">\n      <arg direction=\"out\" type="
        "\"s\"/>\n    </method>\n    <method name=\"localWallet\">\n      <"
        "arg direction=\"out\" type=\"s\"/>\n    </method>\n    <method nam"
        "e=\"pamOpen\">\n      <arg direction=\"in\" type=\"s\" name=\"wall"
        "et\"/>\n      <arg direction=\"in\" type=\"ay\" name=\"passwordHas"
        "h\"/>\n      <arg direction=\"in\" type=\"i\" name=\"sessionTimeou"
        "t\"/>\n      <annotation value=\"true\" name=\"org.freedesktop.DBu"
        "s.Method.NoReply\"/>\n    </method>\n  </interface>\n",
        "allWalletsClosed",
        "",
        "applicationDisconnected",
        "wallet",
        "application",
        "folderListUpdated",
        "folderUpdated",
        "in0",
        "in1",
        "walletAsyncOpened",
        "tId",
        "handle",
        "walletClosed",
        "walletClosedId",
        "walletCreated",
        "walletDeleted",
        "walletListDirty",
        "walletOpened",
        "changePassword",
        "wId",
        "appid",
        "close",
        "force",
        "closeAllWallets",
        "createFolder",
        "folder",
        "deleteWallet",
        "disconnectApplication",
        "entriesList",
        "QVariantMap",
        "entryList",
        "entryType",
        "key",
        "folderDoesNotExist",
        "folderList",
        "hasEntry",
        "hasFolder",
        "isEnabled",
        "isOpen",
        "keyDoesNotExist",
        "localWallet",
        "mapList",
        "networkWallet",
        "open",
        "openAsync",
        "handleSession",
        "openPath",
        "path",
        "openPathAsync",
        "pamOpen",
        "Q_NOREPLY",
        "passwordHash",
        "sessionTimeout",
        "passwordList",
        "readEntry",
        "readEntryList",
        "readMap",
        "readMapList",
        "readPassword",
        "readPasswordList",
        "reconfigure",
        "removeEntry",
        "removeFolder",
        "renameEntry",
        "oldName",
        "newName",
        "sync",
        "users",
        "wallets",
        "writeEntry",
        "value",
        "writeMap",
        "writePassword"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'allWalletsClosed'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applicationDisconnected'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'folderListUpdated'
        QtMocHelpers::SignalData<void(const QString &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'folderUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'walletAsyncOpened'
        QtMocHelpers::SignalData<void(int, int)>(14, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 16 },
        }}),
        // Signal 'walletClosed'
        QtMocHelpers::SignalData<void(int)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'walletClosed'
        QtMocHelpers::SignalData<void(const QString &)>(17, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'walletClosedId'
        QtMocHelpers::SignalData<void(int)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Signal 'walletCreated'
        QtMocHelpers::SignalData<void(const QString &)>(19, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'walletDeleted'
        QtMocHelpers::SignalData<void(const QString &)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Signal 'walletListDirty'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'walletOpened'
        QtMocHelpers::SignalData<void(const QString &)>(22, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'changePassword'
        QtMocHelpers::SlotData<void(const QString &, qlonglong, const QString &)>(23, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::LongLong, 24 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<int(int, bool, const QString &)>(26, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::Bool, 27 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<int(const QString &, bool)>(26, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 8 }, { QMetaType::Bool, 27 },
        }}),
        // Slot 'closeAllWallets'
        QtMocHelpers::SlotData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'createFolder'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &)>(29, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'deleteWallet'
        QtMocHelpers::SlotData<int(const QString &)>(31, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'disconnectApplication'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(32, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Slot 'entriesList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &)>(33, 6, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'entryList'
        QtMocHelpers::SlotData<QStringList(int, const QString &, const QString &)>(35, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'entryType'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &)>(36, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'folderDoesNotExist'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(38, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'folderList'
        QtMocHelpers::SlotData<QStringList(int, const QString &)>(39, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'hasEntry'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &, const QString &)>(40, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'hasFolder'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &)>(41, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'isEnabled'
        QtMocHelpers::SlotData<bool()>(42, 6, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'isOpen'
        QtMocHelpers::SlotData<bool(int)>(43, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'isOpen'
        QtMocHelpers::SlotData<bool(const QString &)>(43, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'keyDoesNotExist'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &)>(44, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'localWallet'
        QtMocHelpers::SlotData<QString()>(45, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'mapList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &)>(46, 6, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'networkWallet'
        QtMocHelpers::SlotData<QString()>(47, 6, QMC::AccessPublic, QMetaType::QString),
        // Slot 'open'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &)>(48, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 8 }, { QMetaType::LongLong, 24 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'openAsync'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &, bool)>(49, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 8 }, { QMetaType::LongLong, 24 }, { QMetaType::QString, 25 }, { QMetaType::Bool, 50 },
        }}),
        // Slot 'openPath'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &)>(51, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 52 }, { QMetaType::LongLong, 24 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'openPathAsync'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &, bool)>(53, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 52 }, { QMetaType::LongLong, 24 }, { QMetaType::QString, 25 }, { QMetaType::Bool, 50 },
        }}),
        // Slot 'pamOpen'
        QtMocHelpers::SlotData<void(const QString &, const QByteArray &, int)>(54, 55, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QByteArray, 56 }, { QMetaType::Int, 57 },
        }}),
        // Slot 'passwordList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &)>(58, 6, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'readEntry'
        QtMocHelpers::SlotData<QByteArray(int, const QString &, const QString &, const QString &)>(59, 6, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'readEntryList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &, const QString &)>(60, 6, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'readMap'
        QtMocHelpers::SlotData<QByteArray(int, const QString &, const QString &, const QString &)>(61, 6, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'readMapList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &, const QString &)>(62, 6, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'readPassword'
        QtMocHelpers::SlotData<QString(int, const QString &, const QString &, const QString &)>(63, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'readPasswordList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &, const QString &)>(64, 6, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<void()>(65, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &)>(66, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'removeFolder'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &)>(67, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'renameEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &, const QString &)>(68, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 69 }, { QMetaType::QString, 70 },
            { QMetaType::QString, 25 },
        }}),
        // Slot 'sync'
        QtMocHelpers::SlotData<void(int, const QString &)>(71, 55, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'users'
        QtMocHelpers::SlotData<QStringList(const QString &)>(72, 6, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'wallets'
        QtMocHelpers::SlotData<QStringList()>(73, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'writeEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QByteArray &, const QString &)>(74, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QByteArray, 75 },
            { QMetaType::QString, 25 },
        }}),
        // Slot 'writeEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QByteArray &, int, const QString &)>(74, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QByteArray, 75 },
            { QMetaType::Int, 36 }, { QMetaType::QString, 25 },
        }}),
        // Slot 'writeMap'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QByteArray &, const QString &)>(76, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QByteArray, 75 },
            { QMetaType::QString, 25 },
        }}),
        // Slot 'writePassword'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &, const QString &)>(77, 6, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 30 }, { QMetaType::QString, 37 }, { QMetaType::QString, 75 },
            { QMetaType::QString, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KWalletAdaptor, qt_meta_tag_ZN14KWalletAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KWalletAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KWalletAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KWalletAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14KWalletAdaptorE_t>.metaTypes,
    nullptr
} };

void KWalletAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->allWalletsClosed(); break;
        case 1: _t->applicationDisconnected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->folderListUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->folderUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->walletAsyncOpened((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->walletClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->walletClosed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->walletClosedId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->walletCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->walletDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->walletListDirty(); break;
        case 11: _t->walletOpened((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->changePassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 13: { int _r = _t->close((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 14: { int _r = _t->close((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->closeAllWallets(); break;
        case 16: { bool _r = _t->createFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { int _r = _t->deleteWallet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->disconnectApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { QVariantMap _r = _t->entriesList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 20: { QStringList _r = _t->entryList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->entryType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->folderDoesNotExist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { QStringList _r = _t->folderList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->hasEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->hasFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->isEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->isOpen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->isOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->keyDoesNotExist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { QString _r = _t->localWallet();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 31: { QVariantMap _r = _t->mapList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 32: { QString _r = _t->networkWallet();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 33: { int _r = _t->open((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: { int _r = _t->openAsync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 35: { int _r = _t->openPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 36: { int _r = _t->openPathAsync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->pamOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 38: { QVariantMap _r = _t->passwordList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 39: { QByteArray _r = _t->readEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 40: { QVariantMap _r = _t->readEntryList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 41: { QByteArray _r = _t->readMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 42: { QVariantMap _r = _t->readMapList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 43: { QString _r = _t->readPassword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 44: { QVariantMap _r = _t->readPasswordList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 45: _t->reconfigure(); break;
        case 46: { int _r = _t->removeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 47: { bool _r = _t->removeFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: { int _r = _t->renameEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->sync((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 50: { QStringList _r = _t->users((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 51: { QStringList _r = _t->wallets();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 52: { int _r = _t->writeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 53: { int _r = _t->writeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 54: { int _r = _t->writeMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->writePassword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)()>(_a, &KWalletAdaptor::allWalletsClosed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(const QString & , const QString & )>(_a, &KWalletAdaptor::applicationDisconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(const QString & )>(_a, &KWalletAdaptor::folderListUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(const QString & , const QString & )>(_a, &KWalletAdaptor::folderUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(int , int )>(_a, &KWalletAdaptor::walletAsyncOpened, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(int )>(_a, &KWalletAdaptor::walletClosed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(const QString & )>(_a, &KWalletAdaptor::walletClosed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(int )>(_a, &KWalletAdaptor::walletClosedId, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(const QString & )>(_a, &KWalletAdaptor::walletCreated, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(const QString & )>(_a, &KWalletAdaptor::walletDeleted, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)()>(_a, &KWalletAdaptor::walletListDirty, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletAdaptor::*)(const QString & )>(_a, &KWalletAdaptor::walletOpened, 11))
            return;
    }
}

const QMetaObject *KWalletAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14KWalletAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KWalletAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 56)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 56;
    }
    return _id;
}

// SIGNAL 0
void KWalletAdaptor::allWalletsClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KWalletAdaptor::applicationDisconnected(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KWalletAdaptor::folderListUpdated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KWalletAdaptor::folderUpdated(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void KWalletAdaptor::walletAsyncOpened(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void KWalletAdaptor::walletClosed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KWalletAdaptor::walletClosed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KWalletAdaptor::walletClosedId(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KWalletAdaptor::walletCreated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void KWalletAdaptor::walletDeleted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KWalletAdaptor::walletListDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KWalletAdaptor::walletOpened(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
