/****************************************************************************
** Meta object code from reading C++ file 'kwalletportalsecretsadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kwalletportalsecretsadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletportalsecretsadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN27KWalletPortalSecretsAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletPortalSecretsAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN27KWalletPortalSecretsAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletPortalSecretsAdaptor",
        "D-Bus Interface",
        "org.freedesktop.impl.portal.Secret",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.impl.portal.Secret\">\n    <me"
        "thod name=\"RetrieveSecret\">\n      <annotation value=\"retrieve_"
        "secret\" name=\"org.gtk.GDBus.C.Name\"/>\n      <annotation value="
        "\"true\" name=\"org.gtk.GDBus.C.UnixFD\"/>\n      <arg direction=\""
        "in\" type=\"o\" name=\"handle\"/>\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"app_id\"/>\n      <arg direction=\"in\" type=\"h\" "
        "name=\"fd\"/>\n      <annotation value=\"QVariantMap\" name=\"org."
        "qtproject.QtDBus.QtTypeName.In3\"/>\n      <arg direction=\"in\" t"
        "ype=\"a{sv}\" name=\"options\"/>\n      <arg direction=\"out\" typ"
        "e=\"u\" name=\"response\"/>\n      <annotation value=\"QVariantMap"
        "\" name=\"org.qtproject.QtDBus.QtTypeName.Out1\"/>\n      <arg dir"
        "ection=\"out\" type=\"a{sv}\" name=\"results\"/>\n    </method>\n "
        "   <property access=\"read\" type=\"u\" name=\"version\"/>\n  </in"
        "terface>\n",
        "RetrieveSecret",
        "",
        "QDBusObjectPath",
        "handle",
        "app_id",
        "QDBusUnixFileDescriptor",
        "fd",
        "QVariantMap",
        "options",
        "QVariantMap&",
        "results",
        "version"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'RetrieveSecret'
        QtMocHelpers::SlotData<uint(const QDBusObjectPath &, const QString &, const QDBusUnixFileDescriptor &, const QVariantMap &, QVariantMap &)>(5, 6, QMC::AccessPublic, QMetaType::UInt, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 }, { 0x80000000 | 12, 13 },
            { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'version'
        QtMocHelpers::PropertyData<uint>(16, QMetaType::UInt, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KWalletPortalSecretsAdaptor, qt_meta_tag_ZN27KWalletPortalSecretsAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KWalletPortalSecretsAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KWalletPortalSecretsAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KWalletPortalSecretsAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27KWalletPortalSecretsAdaptorE_t>.metaTypes,
    nullptr
} };

void KWalletPortalSecretsAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletPortalSecretsAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { uint _r = _t->RetrieveSecret((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusUnixFileDescriptor>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QVariantMap&>>(_a[5])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->version(); break;
        default: break;
        }
    }
}

const QMetaObject *KWalletPortalSecretsAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletPortalSecretsAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27KWalletPortalSecretsAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KWalletPortalSecretsAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
