/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Secrets.Collection.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kwalletfreedesktopcollectionadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KWalletFreedesktopCollectionAdaptor
 */

KWalletFreedesktopCollectionAdaptor::KWalletFreedesktopCollectionAdaptor(KWalletFreedesktopCollection *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KWalletFreedesktopCollectionAdaptor::~KWalletFreedesktopCollectionAdaptor()
{
    // destructor
}

qulonglong KWalletFreedesktopCollectionAdaptor::created() const
{
    // get the value of property Created
    return qvariant_cast< qulonglong >(parent()->property("Created"));
}

QList<QDBusObjectPath> KWalletFreedesktopCollectionAdaptor::items() const
{
    // get the value of property Items
    return qvariant_cast< QList<QDBusObjectPath> >(parent()->property("Items"));
}

QString KWalletFreedesktopCollectionAdaptor::label() const
{
    // get the value of property Label
    return qvariant_cast< QString >(parent()->property("Label"));
}

void KWalletFreedesktopCollectionAdaptor::setLabel(const QString &value)
{
    // set the value of property Label
    parent()->setProperty("Label", QVariant::fromValue(value));
}

bool KWalletFreedesktopCollectionAdaptor::locked() const
{
    // get the value of property Locked
    return qvariant_cast< bool >(parent()->property("Locked"));
}

qulonglong KWalletFreedesktopCollectionAdaptor::modified() const
{
    // get the value of property Modified
    return qvariant_cast< qulonglong >(parent()->property("Modified"));
}

QDBusObjectPath KWalletFreedesktopCollectionAdaptor::CreateItem(PropertiesMap properties, FreedesktopSecret secret, bool replace, QDBusObjectPath &prompt)
{
    // handle method call org.freedesktop.Secret.Collection.CreateItem
    return parent()->CreateItem(properties, secret, replace, prompt);
}

QDBusObjectPath KWalletFreedesktopCollectionAdaptor::Delete()
{
    // handle method call org.freedesktop.Secret.Collection.Delete
    return parent()->Delete();
}

QList<QDBusObjectPath> KWalletFreedesktopCollectionAdaptor::SearchItems(StrStrMap attributes)
{
    // handle method call org.freedesktop.Secret.Collection.SearchItems
    return parent()->SearchItems(attributes);
}


#include "moc_kwalletfreedesktopcollectionadaptor.cpp"
