/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Secrets.Service.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kwalletfreedesktopserviceadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KWalletFreedesktopServiceAdaptor
 */

KWalletFreedesktopServiceAdaptor::KWalletFreedesktopServiceAdaptor(KWalletFreedesktopService *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KWalletFreedesktopServiceAdaptor::~KWalletFreedesktopServiceAdaptor()
{
    // destructor
}

QList<QDBusObjectPath> KWalletFreedesktopServiceAdaptor::collections() const
{
    // get the value of property Collections
    return qvariant_cast< QList<QDBusObjectPath> >(parent()->property("Collections"));
}

QDBusObjectPath KWalletFreedesktopServiceAdaptor::CreateCollection(const QVariantMap &properties, const QString &alias, QDBusObjectPath &prompt)
{
    // handle method call org.freedesktop.Secret.Service.CreateCollection
    return parent()->CreateCollection(properties, alias, prompt);
}

FreedesktopSecretMap KWalletFreedesktopServiceAdaptor::GetSecrets(const QList<QDBusObjectPath> &items, const QDBusObjectPath &session)
{
    // handle method call org.freedesktop.Secret.Service.GetSecrets
    return parent()->GetSecrets(items, session);
}

QList<QDBusObjectPath> KWalletFreedesktopServiceAdaptor::Lock(const QList<QDBusObjectPath> &objects, QDBusObjectPath &Prompt)
{
    // handle method call org.freedesktop.Secret.Service.Lock
    return parent()->Lock(objects, Prompt);
}

QDBusVariant KWalletFreedesktopServiceAdaptor::OpenSession(const QString &algorithm, const QDBusVariant &input, QDBusObjectPath &result)
{
    // handle method call org.freedesktop.Secret.Service.OpenSession
    return parent()->OpenSession(algorithm, input, result);
}

QDBusObjectPath KWalletFreedesktopServiceAdaptor::ReadAlias(const QString &name)
{
    // handle method call org.freedesktop.Secret.Service.ReadAlias
    return parent()->ReadAlias(name);
}

QList<QDBusObjectPath> KWalletFreedesktopServiceAdaptor::SearchItems(StrStrMap attributes, QList<QDBusObjectPath> &locked)
{
    // handle method call org.freedesktop.Secret.Service.SearchItems
    return parent()->SearchItems(attributes, locked);
}

void KWalletFreedesktopServiceAdaptor::SetAlias(const QString &name, const QDBusObjectPath &collection)
{
    // handle method call org.freedesktop.Secret.Service.SetAlias
    parent()->SetAlias(name, collection);
}

QList<QDBusObjectPath> KWalletFreedesktopServiceAdaptor::Unlock(const QList<QDBusObjectPath> &objects, QDBusObjectPath &prompt)
{
    // handle method call org.freedesktop.Secret.Service.Unlock
    return parent()->Unlock(objects, prompt);
}


#include "moc_kwalletfreedesktopserviceadaptor.cpp"
