/****************************************************************************
** Meta object code from reading C++ file 'kwalletd.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kwallet-6.25.0/src/runtime/kwalletd/kwalletd.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletd.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8KWalletDE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletD::qt_create_metaobjectdata<qt_meta_tag_ZN8KWalletDE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletD",
        "walletAsyncOpened",
        "",
        "id",
        "handle",
        "walletListDirty",
        "walletCreated",
        "wallet",
        "walletOpened",
        "walletDeleted",
        "walletClosed",
        "walletClosedId",
        "allWalletsClosed",
        "folderListUpdated",
        "folderUpdated",
        "folder",
        "entryUpdated",
        "key",
        "entryRenamed",
        "oldName",
        "newName",
        "entryDeleted",
        "applicationDisconnected",
        "application",
        "isEnabled",
        "open",
        "wId",
        "appId",
        "openPath",
        "path",
        "openAsync",
        "handleSession",
        "openPathAsync",
        "close",
        "force",
        "sync",
        "Q_NOREPLY",
        "deleteWallet",
        "isOpen",
        "users",
        "changePassword",
        "wallets",
        "folderList",
        "hasFolder",
        "createFolder",
        "removeFolder",
        "entryList",
        "readEntry",
        "readMap",
        "readPassword",
        "readEntryList",
        "QVariantMap",
        "entriesList",
        "readMapList",
        "mapList",
        "readPasswordList",
        "passwordList",
        "renameEntry",
        "writeEntry",
        "value",
        "entryType",
        "writeMap",
        "writePassword",
        "hasEntry",
        "removeEntry",
        "disconnectApplication",
        "reconfigure",
        "folderDoesNotExist",
        "keyDoesNotExist",
        "closeAllWallets",
        "networkWallet",
        "localWallet",
        "pamOpen",
        "passwordHash",
        "sessionTimeout",
        "EntryType",
        "Unknown",
        "Password",
        "Stream",
        "Map",
        "Unused"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'walletAsyncOpened'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Int, 4 },
        }}),
        // Signal 'walletListDirty'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'walletCreated'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'walletOpened'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'walletDeleted'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'walletClosed'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'walletClosed'
        QtMocHelpers::SignalData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'walletClosedId'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'allWalletsClosed'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'folderListUpdated'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'folderUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 15 },
        }}),
        // Signal 'entryUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'entryRenamed'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 15 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
        }}),
        // Signal 'entryDeleted'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 },
        }}),
        // Signal 'applicationDisconnected'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'isEnabled'
        QtMocHelpers::SlotData<bool() const>(24, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'open'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 }, { QMetaType::LongLong, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'openPath'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 29 }, { QMetaType::LongLong, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'openAsync'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &, bool)>(30, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 }, { QMetaType::LongLong, 26 }, { QMetaType::QString, 27 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'openPathAsync'
        QtMocHelpers::SlotData<int(const QString &, qlonglong, const QString &, bool)>(32, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 29 }, { QMetaType::LongLong, 26 }, { QMetaType::QString, 27 }, { QMetaType::Bool, 31 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<int(const QString &, bool)>(33, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 34 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<int(int, bool, const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::Bool, 34 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'sync'
        QtMocHelpers::SlotData<void(int, const QString &)>(35, 36, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'deleteWallet'
        QtMocHelpers::SlotData<int(const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'isOpen'
        QtMocHelpers::SlotData<bool(const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'isOpen'
        QtMocHelpers::SlotData<bool(int)>(38, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'users'
        QtMocHelpers::SlotData<QStringList(const QString &) const>(39, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'changePassword'
        QtMocHelpers::SlotData<void(const QString &, qlonglong, const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::LongLong, 26 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'wallets'
        QtMocHelpers::SlotData<QStringList() const>(41, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'folderList'
        QtMocHelpers::SlotData<QStringList(int, const QString &)>(42, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'hasFolder'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &)>(43, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'createFolder'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &)>(44, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'removeFolder'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &)>(45, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'entryList'
        QtMocHelpers::SlotData<QStringList(int, const QString &, const QString &)>(46, 2, QMC::AccessPublic, QMetaType::QStringList, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'readEntry'
        QtMocHelpers::SlotData<QByteArray(int, const QString &, const QString &, const QString &)>(47, 2, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'readMap'
        QtMocHelpers::SlotData<QByteArray(int, const QString &, const QString &, const QString &)>(48, 2, QMC::AccessPublic, QMetaType::QByteArray, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'readPassword'
        QtMocHelpers::SlotData<QString(int, const QString &, const QString &, const QString &)>(49, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'readEntryList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &, const QString &)>(50, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'entriesList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &)>(52, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'readMapList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &, const QString &)>(53, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'mapList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &)>(54, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'readPasswordList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &, const QString &)>(55, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'passwordList'
        QtMocHelpers::SlotData<QVariantMap(int, const QString &, const QString &)>(56, 2, QMC::AccessPublic, 0x80000000 | 51, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'renameEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &, const QString &)>(57, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 19 }, { QMetaType::QString, 20 },
            { QMetaType::QString, 27 },
        }}),
        // Slot 'writeEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QByteArray &, int, const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QByteArray, 59 },
            { QMetaType::Int, 60 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'writeEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QByteArray &, const QString &)>(58, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QByteArray, 59 },
            { QMetaType::QString, 27 },
        }}),
        // Slot 'writeMap'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QByteArray &, const QString &)>(61, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QByteArray, 59 },
            { QMetaType::QString, 27 },
        }}),
        // Slot 'writePassword'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &, const QString &)>(62, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 59 },
            { QMetaType::QString, 27 },
        }}),
        // Slot 'hasEntry'
        QtMocHelpers::SlotData<bool(int, const QString &, const QString &, const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'entryType'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &)>(60, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'removeEntry'
        QtMocHelpers::SlotData<int(int, const QString &, const QString &, const QString &)>(64, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 }, { QMetaType::QString, 27 },
        }}),
        // Slot 'disconnectApplication'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'folderDoesNotExist'
        QtMocHelpers::SlotData<bool(const QString &, const QString &)>(67, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 15 },
        }}),
        // Slot 'keyDoesNotExist'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &)>(68, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 15 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'closeAllWallets'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'networkWallet'
        QtMocHelpers::SlotData<QString()>(70, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'localWallet'
        QtMocHelpers::SlotData<QString()>(71, 2, QMC::AccessPublic, QMetaType::QString),
        // Slot 'pamOpen'
        QtMocHelpers::SlotData<int(const QString &, const QByteArray &, int)>(72, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 7 }, { QMetaType::QByteArray, 73 }, { QMetaType::Int, 74 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'EntryType'
        QtMocHelpers::EnumData<enum EntryType>(75, 75, QMC::EnumFlags{}).add({
            {   76, EntryType::Unknown },
            {   77, EntryType::Password },
            {   78, EntryType::Stream },
            {   79, EntryType::Map },
            {   80, EntryType::Unused },
        }),
    };
    return QtMocHelpers::metaObjectData<KWalletD, qt_meta_tag_ZN8KWalletDE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWalletD::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWalletDE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWalletDE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8KWalletDE_t>.metaTypes,
    nullptr
} };

void KWalletD::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletD *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->walletAsyncOpened((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->walletListDirty(); break;
        case 2: _t->walletCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->walletOpened((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->walletDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->walletClosed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->walletClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->walletClosedId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->allWalletsClosed(); break;
        case 9: _t->folderListUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->folderUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 11: _t->entryUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 12: _t->entryRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 13: _t->entryDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 14: _t->applicationDisconnected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 15: { bool _r = _t->isEnabled();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->open((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { int _r = _t->openPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 18: { int _r = _t->openAsync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 19: { int _r = _t->openPathAsync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { int _r = _t->close((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: { int _r = _t->close((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->sync((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: { int _r = _t->deleteWallet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->isOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: { bool _r = _t->isOpen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 26: { QStringList _r = _t->users((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 27: _t->changePassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 28: { QStringList _r = _t->wallets();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 29: { QStringList _r = _t->folderList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->hasFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->createFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->removeFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { QStringList _r = _t->entryList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 34: { QByteArray _r = _t->readEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 35: { QByteArray _r = _t->readMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 36: { QString _r = _t->readPassword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 37: { QVariantMap _r = _t->readEntryList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 38: { QVariantMap _r = _t->entriesList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 39: { QVariantMap _r = _t->readMapList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 40: { QVariantMap _r = _t->mapList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 41: { QVariantMap _r = _t->readPasswordList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 42: { QVariantMap _r = _t->passwordList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantMap*>(_a[0]) = std::move(_r); }  break;
        case 43: { int _r = _t->renameEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 44: { int _r = _t->writeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 45: { int _r = _t->writeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 46: { int _r = _t->writeMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 47: { int _r = _t->writePassword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 48: { bool _r = _t->hasEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { int _r = _t->entryType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 50: { int _r = _t->removeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->disconnectApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: _t->reconfigure(); break;
        case 53: { bool _r = _t->folderDoesNotExist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: { bool _r = _t->keyDoesNotExist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->closeAllWallets(); break;
        case 56: { QString _r = _t->networkWallet();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 57: { QString _r = _t->localWallet();
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 58: { int _r = _t->pamOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(int , int )>(_a, &KWalletD::walletAsyncOpened, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)()>(_a, &KWalletD::walletListDirty, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & )>(_a, &KWalletD::walletCreated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & )>(_a, &KWalletD::walletOpened, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & )>(_a, &KWalletD::walletDeleted, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & )>(_a, &KWalletD::walletClosed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(int )>(_a, &KWalletD::walletClosed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(int )>(_a, &KWalletD::walletClosedId, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)()>(_a, &KWalletD::allWalletsClosed, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & )>(_a, &KWalletD::folderListUpdated, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & , const QString & )>(_a, &KWalletD::folderUpdated, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & , const QString & , const QString & )>(_a, &KWalletD::entryUpdated, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & , const QString & , const QString & , const QString & )>(_a, &KWalletD::entryRenamed, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & , const QString & , const QString & )>(_a, &KWalletD::entryDeleted, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletD::*)(const QString & , const QString & )>(_a, &KWalletD::applicationDisconnected, 14))
            return;
    }
}

const QMetaObject *KWalletD::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletD::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8KWalletDE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int KWalletD::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 59)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 59;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 59)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 59;
    }
    return _id;
}

// SIGNAL 0
void KWalletD::walletAsyncOpened(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KWalletD::walletListDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KWalletD::walletCreated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KWalletD::walletOpened(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KWalletD::walletDeleted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KWalletD::walletClosed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KWalletD::walletClosed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KWalletD::walletClosedId(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KWalletD::allWalletsClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KWalletD::folderListUpdated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KWalletD::folderUpdated(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void KWalletD::entryUpdated(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2, _t3);
}

// SIGNAL 12
void KWalletD::entryRenamed(const QString & _t1, const QString & _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 13
void KWalletD::entryDeleted(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void KWalletD::applicationDisconnected(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2);
}
QT_WARNING_POP
