/********************************************************************************
** Form generated from reading UI file 'knewwalletdialogintro.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KNEWWALLETDIALOGINTRO_H
#define UI_KNEWWALLETDIALOGINTRO_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_KNewWalletDialogIntro
{
public:
    QVBoxLayout *verticalLayout_2;
    KTitleWidget *ktitlewidget;
    QLabel *labelIntro;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *verticalLayout;
    QRadioButton *radioBlowfish;
    QRadioButton *radioGpg;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QWidget *KNewWalletDialogIntro)
    {
        if (KNewWalletDialogIntro->objectName().isEmpty())
            KNewWalletDialogIntro->setObjectName("KNewWalletDialogIntro");
        KNewWalletDialogIntro->resize(341, 190);
        verticalLayout_2 = new QVBoxLayout(KNewWalletDialogIntro);
        verticalLayout_2->setObjectName("verticalLayout_2");
        ktitlewidget = new KTitleWidget(KNewWalletDialogIntro);
        ktitlewidget->setObjectName("ktitlewidget");

        verticalLayout_2->addWidget(ktitlewidget);

        labelIntro = new QLabel(KNewWalletDialogIntro);
        labelIntro->setObjectName("labelIntro");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(labelIntro->sizePolicy().hasHeightForWidth());
        labelIntro->setSizePolicy(sizePolicy);
        labelIntro->setTextFormat(Qt::RichText);
        labelIntro->setAlignment(Qt::AlignVCenter);
        labelIntro->setWordWrap(true);
        labelIntro->setMargin(12);

        verticalLayout_2->addWidget(labelIntro);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        radioBlowfish = new QRadioButton(KNewWalletDialogIntro);
        radioBlowfish->setObjectName("radioBlowfish");

        verticalLayout->addWidget(radioBlowfish);

        radioGpg = new QRadioButton(KNewWalletDialogIntro);
        radioGpg->setObjectName("radioGpg");
        radioGpg->setChecked(true);

        verticalLayout->addWidget(radioGpg);


        horizontalLayout->addLayout(verticalLayout);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout_2->addLayout(horizontalLayout);


        retranslateUi(KNewWalletDialogIntro);
        QObject::connect(radioBlowfish, SIGNAL(toggled(bool)), KNewWalletDialogIntro, SLOT(onBlowfishToggled(bool)));

        QMetaObject::connectSlotsByName(KNewWalletDialogIntro);
    } // setupUi

    void retranslateUi(QWidget *KNewWalletDialogIntro)
    {
        ktitlewidget->setComment(tr2i18n("The KDE Wallet System", nullptr));
        labelIntro->setText(tr2i18n("<html><head/><body><p>The application '<span style=\" font-weight:600;\">%1</span>' has requested to open the KDE wallet. This is used to store sensitive data in a secure fashion. Please choose the new wallet's type below or click cancel to deny the application's request.</p></body></html>", nullptr));
        radioBlowfish->setText(tr2i18n("Classic, blowfish encrypted file", nullptr));
        radioGpg->setText(tr2i18n("Use GPG encryption, for better protection", nullptr));
        (void)KNewWalletDialogIntro;
    } // retranslateUi

};

namespace Ui {
    class KNewWalletDialogIntro: public Ui_KNewWalletDialogIntro {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KNEWWALLETDIALOGINTRO_H

