/********************************************************************************
** Form generated from reading UI file 'kwalletwizardpagegpgkey.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KWALLETWIZARDPAGEGPGKEY_H
#define UI_KWALLETWIZARDPAGEGPGKEY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KWalletWizardPageGpgKey
{
public:
    QVBoxLayout *verticalLayout_3;
    QStackedWidget *stackedWidget;
    QWidget *_pageWhenHasKeys;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *_gpgKey;
    QSpacerItem *verticalSpacer;
    QWidget *_pageNoKeys;
    QVBoxLayout *verticalLayout;
    QLabel *label_2;

    void setupUi(QWidget *KWalletWizardPageGpgKey)
    {
        if (KWalletWizardPageGpgKey->objectName().isEmpty())
            KWalletWizardPageGpgKey->setObjectName("KWalletWizardPageGpgKey");
        KWalletWizardPageGpgKey->resize(436, 309);
        verticalLayout_3 = new QVBoxLayout(KWalletWizardPageGpgKey);
        verticalLayout_3->setObjectName("verticalLayout_3");
        stackedWidget = new QStackedWidget(KWalletWizardPageGpgKey);
        stackedWidget->setObjectName("stackedWidget");
        _pageWhenHasKeys = new QWidget();
        _pageWhenHasKeys->setObjectName("_pageWhenHasKeys");
        verticalLayout_2 = new QVBoxLayout(_pageWhenHasKeys);
        verticalLayout_2->setObjectName("verticalLayout_2");
        label_3 = new QLabel(_pageWhenHasKeys);
        label_3->setObjectName("label_3");
        label_3->setTextFormat(Qt::AutoText);
        label_3->setWordWrap(true);

        verticalLayout_2->addWidget(label_3);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(_pageWhenHasKeys);
        label->setObjectName("label");
        label->setEnabled(true);

        horizontalLayout->addWidget(label);

        _gpgKey = new QComboBox(_pageWhenHasKeys);
        _gpgKey->setObjectName("_gpgKey");
        _gpgKey->setEnabled(true);

        horizontalLayout->addWidget(_gpgKey);


        verticalLayout_2->addLayout(horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 173, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout_2->addItem(verticalSpacer);

        stackedWidget->addWidget(_pageWhenHasKeys);
        _pageNoKeys = new QWidget();
        _pageNoKeys->setObjectName("_pageNoKeys");
        verticalLayout = new QVBoxLayout(_pageNoKeys);
        verticalLayout->setObjectName("verticalLayout");
        label_2 = new QLabel(_pageNoKeys);
        label_2->setObjectName("label_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy);
        label_2->setWordWrap(true);

        verticalLayout->addWidget(label_2);

        stackedWidget->addWidget(_pageNoKeys);

        verticalLayout_3->addWidget(stackedWidget);


        retranslateUi(KWalletWizardPageGpgKey);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(KWalletWizardPageGpgKey);
    } // setupUi

    void retranslateUi(QWidget *KWalletWizardPageGpgKey)
    {
        label_3->setText(tr2i18n("<html><head/><body><p>The GPG-based wallet use a GPG encryption key to securely encrypt data on disk. The key must be available when decrypting is needed or your wallet will not be accessible. For example, if you choose a SmartCard-based encryption key, the GPG system will prompt you to enter it and its associated PIN when attempting to open the wallet. <span style=\" font-weight:600;\">NOTE:</span> this list contains only &quot;ultimate-level&quot; trusted keys.</p></body></html>", nullptr));
        label->setText(tr2i18n("Select encryption GPG key:", nullptr));
        label_2->setText(tr2i18n("Unable to locate at least one <b>encrypting GPG key</b>. KDE Wallet needs such <b>encrypting key</b> to securely store passwords or other sensitive data on disk. If you still want to setup a GPG-based wallet, then cancel this wizard, set-up an <b>encrypting GPG key</b>, then retry this assistant. Otherwise, you may still click back, then choose a classic, blowfish encrypted file format on the previous page.", nullptr));
        (void)KWalletWizardPageGpgKey;
    } // retranslateUi

};

namespace Ui {
    class KWalletWizardPageGpgKey: public Ui_KWalletWizardPageGpgKey {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KWALLETWIZARDPAGEGPGKEY_H

