/****************************************************************************
** Meta object code from reading C++ file 'kwalletfreedesktopitemadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kwalletfreedesktopitemadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletfreedesktopitemadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN29KWalletFreedesktopItemAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletFreedesktopItemAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN29KWalletFreedesktopItemAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletFreedesktopItemAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Secret.Item",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Secret.Item\">\n    <property "
        "access=\"read\" type=\"b\" name=\"Locked\"/>\n    <property access"
        "=\"readwrite\" type=\"a{ss}\" name=\"Attributes\">\n      <annotat"
        "ion value=\"StrStrMap\" name=\"org.qtproject.QtDBus.QtTypeName\"/>"
        "\n    </property>\n    <property access=\"readwrite\" type=\"s\" n"
        "ame=\"Label\"/>\n    <property access=\"readwrite\" type=\"s\" nam"
        "e=\"Type\"/>\n    <property access=\"read\" type=\"t\" name=\"Crea"
        "ted\"/>\n    <property access=\"read\" type=\"t\" name=\"Modified\""
        "/>\n    <method name=\"Delete\">\n      <arg direction=\"out\" typ"
        "e=\"o\" name=\"Prompt\"/>\n    </method>\n    <method name=\"GetSe"
        "cret\">\n      <arg direction=\"in\" type=\"o\" name=\"session\"/>"
        "\n      <arg direction=\"out\" type=\"(oayays)\" name=\"secret\"/>"
        "\n      <annotation value=\"FreedesktopSecret\" name=\"org.qtproje"
        "ct.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <method name=\"S"
        "etSecret\">\n      <arg direction=\"in\" type=\"(oayays)\" name=\""
        "secret\"/>\n      <annotation value=\"FreedesktopSecret\" name=\"o"
        "rg.qtproject.QtDBus.QtTypeName.In0\"/>\n    </method>\n  </interfa"
        "ce>\n",
        "Delete",
        "QDBusObjectPath",
        "",
        "GetSecret",
        "FreedesktopSecret",
        "session",
        "SetSecret",
        "secret",
        "Attributes",
        "StrStrMap",
        "Created",
        "Label",
        "Locked",
        "Modified",
        "Type"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusObjectPath()>(5, 7, QMC::AccessPublic, 0x80000000 | 6),
        // Slot 'GetSecret'
        QtMocHelpers::SlotData<FreedesktopSecret(const QDBusObjectPath &)>(8, 7, QMC::AccessPublic, 0x80000000 | 9, {{
            { 0x80000000 | 6, 10 },
        }}),
        // Slot 'SetSecret'
        QtMocHelpers::SlotData<void(FreedesktopSecret)>(11, 7, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Attributes'
        QtMocHelpers::PropertyData<StrStrMap>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'Created'
        QtMocHelpers::PropertyData<qulonglong>(15, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Label'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(17, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Modified'
        QtMocHelpers::PropertyData<qulonglong>(18, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Type'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KWalletFreedesktopItemAdaptor, qt_meta_tag_ZN29KWalletFreedesktopItemAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KWalletFreedesktopItemAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29KWalletFreedesktopItemAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29KWalletFreedesktopItemAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN29KWalletFreedesktopItemAdaptorE_t>.metaTypes,
    nullptr
} };

void KWalletFreedesktopItemAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletFreedesktopItemAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusObjectPath _r = _t->Delete();
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 1: { FreedesktopSecret _r = _t->GetSecret((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<FreedesktopSecret*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->SetSecret((*reinterpret_cast<std::add_pointer_t<FreedesktopSecret>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FreedesktopSecret >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< StrStrMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<StrStrMap*>(_v) = _t->attributes(); break;
        case 1: *reinterpret_cast<qulonglong*>(_v) = _t->created(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 4: *reinterpret_cast<qulonglong*>(_v) = _t->modified(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAttributes(*reinterpret_cast<StrStrMap*>(_v)); break;
        case 2: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setType(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KWalletFreedesktopItemAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletFreedesktopItemAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN29KWalletFreedesktopItemAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KWalletFreedesktopItemAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
