/********************************************************************************
** Form generated from reading UI file 'kwalletwizardpagepasswordgpg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KWALLETWIZARDPAGEPASSWORDGPG_H
#define UI_KWALLETWIZARDPAGEPASSWORDGPG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KWalletWizardPagePasswordGpg
{
public:
    QVBoxLayout *verticalLayout_2;
    QLabel *textLabel3;
    QCheckBox *_useWallet;
    QGroupBox *_groupBox;
    QVBoxLayout *verticalLayout;
    QRadioButton *_radioGpg;
    QRadioButton *_radioBlowfish;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *spacerItem;
    QHBoxLayout *horizontalLayout;
    QVBoxLayout *vboxLayout;
    QLabel *textLabel1_3;
    QLabel *textLabel2_3;
    QVBoxLayout *vboxLayout1;
    QLineEdit *_pass1;
    QLineEdit *_pass2;
    QSpacerItem *spacerItem1;
    QLabel *_matchLabel;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *KWalletWizardPagePasswordGpg)
    {
        if (KWalletWizardPagePasswordGpg->objectName().isEmpty())
            KWalletWizardPagePasswordGpg->setObjectName("KWalletWizardPagePasswordGpg");
        KWalletWizardPagePasswordGpg->resize(448, 385);
        verticalLayout_2 = new QVBoxLayout(KWalletWizardPagePasswordGpg);
        verticalLayout_2->setObjectName("verticalLayout_2");
        textLabel3 = new QLabel(KWalletWizardPagePasswordGpg);
        textLabel3->setObjectName("textLabel3");
        textLabel3->setTextFormat(Qt::RichText);
        textLabel3->setWordWrap(true);

        verticalLayout_2->addWidget(textLabel3);

        _useWallet = new QCheckBox(KWalletWizardPagePasswordGpg);
        _useWallet->setObjectName("_useWallet");

        verticalLayout_2->addWidget(_useWallet);

        _groupBox = new QGroupBox(KWalletWizardPagePasswordGpg);
        _groupBox->setObjectName("_groupBox");
        _groupBox->setEnabled(false);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(_groupBox->sizePolicy().hasHeightForWidth());
        _groupBox->setSizePolicy(sizePolicy);
        verticalLayout = new QVBoxLayout(_groupBox);
        verticalLayout->setObjectName("verticalLayout");
        _radioGpg = new QRadioButton(_groupBox);
        _radioGpg->setObjectName("_radioGpg");
        _radioGpg->setEnabled(false);
        _radioGpg->setChecked(true);

        verticalLayout->addWidget(_radioGpg);

        _radioBlowfish = new QRadioButton(_groupBox);
        _radioBlowfish->setObjectName("_radioBlowfish");
        _radioBlowfish->setEnabled(false);

        verticalLayout->addWidget(_radioBlowfish);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        spacerItem = new QSpacerItem(28, 28, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(spacerItem);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        vboxLayout = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(0, 0, 0, 0);
#endif
        vboxLayout->setObjectName("vboxLayout");
        textLabel1_3 = new QLabel(_groupBox);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setEnabled(false);
        textLabel1_3->setAlignment(Qt::AlignAbsolute|Qt::AlignBottom|Qt::AlignCenter|Qt::AlignHCenter|Qt::AlignHorizontal_Mask|Qt::AlignJustify|Qt::AlignLeading|Qt::AlignLeft|Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing|Qt::AlignVCenter|Qt::AlignVertical_Mask);

        vboxLayout->addWidget(textLabel1_3);

        textLabel2_3 = new QLabel(_groupBox);
        textLabel2_3->setObjectName("textLabel2_3");
        textLabel2_3->setEnabled(false);
        textLabel2_3->setAlignment(Qt::AlignAbsolute|Qt::AlignBottom|Qt::AlignCenter|Qt::AlignHCenter|Qt::AlignHorizontal_Mask|Qt::AlignJustify|Qt::AlignLeading|Qt::AlignLeft|Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing|Qt::AlignVCenter|Qt::AlignVertical_Mask);

        vboxLayout->addWidget(textLabel2_3);


        horizontalLayout->addLayout(vboxLayout);

        vboxLayout1 = new QVBoxLayout();
#ifndef UI_Q_OS_MAC
        vboxLayout1->setSpacing(6);
#endif
        vboxLayout1->setContentsMargins(0, 0, 0, 0);
        vboxLayout1->setObjectName("vboxLayout1");
        _pass1 = new QLineEdit(_groupBox);
        _pass1->setObjectName("_pass1");
        _pass1->setEnabled(false);
        _pass1->setEchoMode(QLineEdit::Password);

        vboxLayout1->addWidget(_pass1);

        _pass2 = new QLineEdit(_groupBox);
        _pass2->setObjectName("_pass2");
        _pass2->setEnabled(false);
        _pass2->setEchoMode(QLineEdit::Password);

        vboxLayout1->addWidget(_pass2);


        horizontalLayout->addLayout(vboxLayout1);


        horizontalLayout_2->addLayout(horizontalLayout);

        spacerItem1 = new QSpacerItem(98, 18, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(spacerItem1);


        verticalLayout->addLayout(horizontalLayout_2);

        _matchLabel = new QLabel(_groupBox);
        _matchLabel->setObjectName("_matchLabel");
        _matchLabel->setAlignment(Qt::AlignAbsolute|Qt::AlignBottom|Qt::AlignCenter|Qt::AlignHCenter|Qt::AlignHorizontal_Mask|Qt::AlignJustify|Qt::AlignLeading|Qt::AlignLeft|Qt::AlignRight|Qt::AlignTop|Qt::AlignTrailing|Qt::AlignVCenter|Qt::AlignVertical_Mask);

        verticalLayout->addWidget(_matchLabel);

        verticalSpacer = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        verticalLayout_2->addWidget(_groupBox);

#if QT_CONFIG(shortcut)
        textLabel1_3->setBuddy(_pass1);
        textLabel2_3->setBuddy(_pass2);
#endif // QT_CONFIG(shortcut)

        retranslateUi(KWalletWizardPagePasswordGpg);
        QObject::connect(_radioBlowfish, &QRadioButton::toggled, textLabel1_3, &QLabel::setEnabled);
        QObject::connect(_radioBlowfish, &QRadioButton::toggled, _pass1, &QLineEdit::setEnabled);
        QObject::connect(_radioBlowfish, &QRadioButton::toggled, textLabel2_3, &QLabel::setEnabled);
        QObject::connect(_radioBlowfish, &QRadioButton::toggled, _pass2, &QLineEdit::setEnabled);
        QObject::connect(_radioBlowfish, &QRadioButton::clicked, _pass1, qOverload<>(&QLineEdit::setFocus));
        QObject::connect(_useWallet, &QCheckBox::toggled, _groupBox, &QGroupBox::setEnabled);
        QObject::connect(_useWallet, &QCheckBox::toggled, _radioGpg, &QRadioButton::setEnabled);
        QObject::connect(_useWallet, &QCheckBox::toggled, _radioBlowfish, &QRadioButton::setEnabled);

        QMetaObject::connectSlotsByName(KWalletWizardPagePasswordGpg);
    } // setupUi

    void retranslateUi(QWidget *KWalletWizardPagePasswordGpg)
    {
        textLabel3->setText(tr2i18n("<html><head/><body><p>Various applications may attempt to use the KDE wallet to store passwords or other information such as web form data and cookies. If you would like these applications to use the wallet, you must enable it now and choose method for its encryption.</p><p>GPG method is more secure, but you must have configured at least one encrypting key on your system.</p><p>If you choose the classic format, be warned that the password you choose <span style=\" font-style:italic;\">cannot</span> be recovered if it is lost, and will allow anyone who knows it to obtain all the information contained in the wallet.</p></body></html>", nullptr));
        _useWallet->setText(tr2i18n("Yes, I wish to use the KDE wallet to store my personal information.", nullptr));
        _groupBox->setTitle(tr2i18n("What kind of encryption do you wish?", nullptr));
        _radioGpg->setText(tr2i18n("Use GPG encryption, for better protection", nullptr));
        _radioBlowfish->setText(tr2i18n("Classic, blowfish encrypted file", nullptr));
        textLabel1_3->setText(tr2i18n("Enter a new password:", nullptr));
        textLabel2_3->setText(tr2i18n("Verify password:", nullptr));
        _matchLabel->setText(QString());
        (void)KWalletWizardPagePasswordGpg;
    } // retranslateUi

};

namespace Ui {
    class KWalletWizardPagePasswordGpg: public Ui_KWalletWizardPagePasswordGpg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KWALLETWIZARDPAGEPASSWORDGPG_H

