/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Secrets.Prompt.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KWALLETFREEDESKTOPPROMPTADAPTOR_H
#define KWALLETFREEDESKTOPPROMPTADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kwalletfreedesktopprompt.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Secret.Prompt
 */
class KWalletFreedesktopPromptAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Secret.Prompt")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Secret.Prompt\">\n"
"    <method name=\"Prompt\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"window_id\"/>\n"
"    </method>\n"
"    <method name=\"Dismiss\"/>\n"
"    <signal name=\"Completed\">\n"
"      <arg type=\"b\" name=\"dismissed\"/>\n"
"      <arg type=\"v\" name=\"result\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    KWalletFreedesktopPromptAdaptor(KWalletFreedesktopPrompt *parent);
    ~KWalletFreedesktopPromptAdaptor() override;

    inline KWalletFreedesktopPrompt *parent() const
    { return static_cast<KWalletFreedesktopPrompt *>(QObject::parent()); }

public: // PROPERTIES
public Q_SLOTS: // METHODS
    void Dismiss();
    void Prompt(const QString &window_id);
Q_SIGNALS: // SIGNALS
    void Completed(bool dismissed, const QDBusVariant &result);
};

#endif
