/********************************************************************************
** Form generated from reading UI file 'knewwalletdialoggpg.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KNEWWALLETDIALOGGPG_H
#define UI_KNEWWALLETDIALOGGPG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KNewWalletDialogGpg
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QLabel *label_2;
    QTableWidget *listCertificates;

    void setupUi(QWidget *KNewWalletDialogGpg)
    {
        if (KNewWalletDialogGpg->objectName().isEmpty())
            KNewWalletDialogGpg->setObjectName("KNewWalletDialogGpg");
        KNewWalletDialogGpg->resize(400, 300);
        verticalLayout = new QVBoxLayout(KNewWalletDialogGpg);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(KNewWalletDialogGpg);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        label_2 = new QLabel(KNewWalletDialogGpg);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        listCertificates = new QTableWidget(KNewWalletDialogGpg);
        if (listCertificates->columnCount() < 3)
            listCertificates->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        listCertificates->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        listCertificates->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        listCertificates->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        listCertificates->setObjectName("listCertificates");
        listCertificates->setProperty("showDropIndicator", QVariant(false));
        listCertificates->setDragDropOverwriteMode(false);
        listCertificates->setSelectionBehavior(QAbstractItemView::SelectRows);
        listCertificates->setShowGrid(false);
        listCertificates->setColumnCount(3);
        listCertificates->horizontalHeader()->setCascadingSectionResizes(true);
        listCertificates->horizontalHeader()->setProperty("showSortIndicator", QVariant(true));
        listCertificates->verticalHeader()->setVisible(false);
        listCertificates->verticalHeader()->setHighlightSections(false);

        verticalLayout->addWidget(listCertificates);


        retranslateUi(KNewWalletDialogGpg);
        QObject::connect(listCertificates, SIGNAL(itemSelectionChanged()), KNewWalletDialogGpg, SLOT(onItemSelectionChanged()));

        QMetaObject::connectSlotsByName(KNewWalletDialogGpg);
    } // setupUi

    void retranslateUi(QWidget *KNewWalletDialogGpg)
    {
        label->setText(tr2i18n("Please select the signing key from the list below:", nullptr));
        label_2->setText(tr2i18n("<html><head/><body><p><span style=\" font-weight:600;\">NOTE:</span> this list shows only &quot;ultimate-level&quot; trusted keys</p></body></html>", nullptr));
        QTableWidgetItem *___qtablewidgetitem = listCertificates->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(tr2i18n("Name", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = listCertificates->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(tr2i18n("E-Mail", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = listCertificates->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(tr2i18n("Key-ID", nullptr));
        (void)KNewWalletDialogGpg;
    } // retranslateUi

};

namespace Ui {
    class KNewWalletDialogGpg: public Ui_KNewWalletDialogGpg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KNEWWALLETDIALOGGPG_H

