/****************************************************************************
** Meta object code from reading C++ file 'kwalletfreedesktopitem.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kwallet-6.25.0/src/runtime/ksecretd/kwalletfreedesktopitem.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletfreedesktopitem.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22KWalletFreedesktopItemE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletFreedesktopItem::qt_create_metaobjectdata<qt_meta_tag_ZN22KWalletFreedesktopItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletFreedesktopItem",
        "Delete",
        "QDBusObjectPath",
        "",
        "GetSecret",
        "FreedesktopSecret",
        "session",
        "SetSecret",
        "secret",
        "Attributes",
        "StrStrMap",
        "Created",
        "Label",
        "Locked",
        "Modified",
        "Type"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusObjectPath()>(1, 3, QMC::AccessPublic, 0x80000000 | 2),
        // Slot 'GetSecret'
        QtMocHelpers::SlotData<FreedesktopSecret(const QDBusObjectPath &)>(4, 3, QMC::AccessPublic, 0x80000000 | 5, {{
            { 0x80000000 | 2, 6 },
        }}),
        // Slot 'SetSecret'
        QtMocHelpers::SlotData<void(const FreedesktopSecret &)>(7, 3, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 8 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Attributes'
        QtMocHelpers::PropertyData<StrStrMap>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'Created'
        QtMocHelpers::PropertyData<qulonglong>(11, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Label'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(13, QMetaType::Bool, QMC::DefaultPropertyFlags),
        // property 'Modified'
        QtMocHelpers::PropertyData<qulonglong>(14, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Type'
        QtMocHelpers::PropertyData<QString>(15, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KWalletFreedesktopItem, qt_meta_tag_ZN22KWalletFreedesktopItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWalletFreedesktopItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KWalletFreedesktopItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KWalletFreedesktopItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KWalletFreedesktopItemE_t>.metaTypes,
    nullptr
} };

void KWalletFreedesktopItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletFreedesktopItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusObjectPath _r = _t->Delete();
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 1: { FreedesktopSecret _r = _t->GetSecret((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1])));
            if (_a[0]) *reinterpret_cast<FreedesktopSecret*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->SetSecret((*reinterpret_cast<std::add_pointer_t<FreedesktopSecret>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FreedesktopSecret >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< StrStrMap >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<StrStrMap*>(_v) = _t->attributes(); break;
        case 1: *reinterpret_cast<qulonglong*>(_v) = _t->created(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        case 4: *reinterpret_cast<qulonglong*>(_v) = _t->modified(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->type(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAttributes(*reinterpret_cast<StrStrMap*>(_v)); break;
        case 2: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setType(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KWalletFreedesktopItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletFreedesktopItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KWalletFreedesktopItemE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int KWalletFreedesktopItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}
QT_WARNING_POP
