/****************************************************************************
** Meta object code from reading C++ file 'kwallet_interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kwallet_interface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwallet_interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22OrgKdeKWalletInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKWalletInterface::qt_create_metaobjectdata<qt_meta_tag_ZN22OrgKdeKWalletInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKWalletInterface",
        "allWalletsClosed",
        "",
        "applicationDisconnected",
        "wallet",
        "application",
        "folderListUpdated",
        "folderUpdated",
        "in0",
        "in1",
        "walletAsyncOpened",
        "tId",
        "handle",
        "walletClosed",
        "Q_DECL_DEPRECATED",
        "walletClosedId",
        "walletCreated",
        "walletDeleted",
        "walletListDirty",
        "walletOpened",
        "changePassword",
        "QDBusPendingReply<>",
        "wId",
        "appid",
        "close",
        "QDBusPendingReply<int>",
        "force",
        "closeAllWallets",
        "createFolder",
        "QDBusPendingReply<bool>",
        "folder",
        "deleteWallet",
        "disconnectApplication",
        "entriesList",
        "QDBusPendingReply<QVariantMap>",
        "entryList",
        "QDBusPendingReply<QStringList>",
        "entryType",
        "key",
        "folderDoesNotExist",
        "folderList",
        "hasEntry",
        "hasFolder",
        "isEnabled",
        "isOpen",
        "keyDoesNotExist",
        "localWallet",
        "QDBusPendingReply<QString>",
        "mapList",
        "networkWallet",
        "open",
        "openAsync",
        "handleSession",
        "openPath",
        "path",
        "openPathAsync",
        "pamOpen",
        "Q_NOREPLY",
        "passwordHash",
        "sessionTimeout",
        "passwordList",
        "readEntry",
        "QDBusPendingReply<QByteArray>",
        "readEntryList",
        "readMap",
        "readMapList",
        "readPassword",
        "readPasswordList",
        "reconfigure",
        "removeEntry",
        "removeFolder",
        "renameEntry",
        "oldName",
        "newName",
        "sync",
        "users",
        "wallets",
        "writeEntry",
        "value",
        "writeMap",
        "writePassword"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'allWalletsClosed'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applicationDisconnected'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Signal 'folderListUpdated'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'folderUpdated'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'walletAsyncOpened'
        QtMocHelpers::SignalData<void(int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 },
        }}),
        // Signal 'walletClosed'
        QtMocHelpers::SignalData<void(int)>(13, 14, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'walletClosed'
        QtMocHelpers::SignalData<void(const QString &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'walletClosedId'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Signal 'walletCreated'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'walletDeleted'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'walletListDirty'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'walletOpened'
        QtMocHelpers::SignalData<void(const QString &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'changePassword'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &, qlonglong, const QString &)>(20, 2, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 4 }, { QMetaType::LongLong, 22 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, bool, const QString &)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::Bool, 26 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'close'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &, bool)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 4 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'closeAllWallets'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(27, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'createFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QString &, const QString &)>(28, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'deleteWallet'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &)>(31, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'disconnectApplication'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, const QString &)>(32, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 5 },
        }}),
        // Slot 'entriesList'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(int, const QString &, const QString &)>(33, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'entryList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(int, const QString &, const QString &)>(35, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'entryType'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, const QString &, const QString &, const QString &)>(37, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'folderDoesNotExist'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, const QString &)>(39, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 30 },
        }}),
        // Slot 'folderList'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(int, const QString &)>(40, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'hasEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QString &, const QString &, const QString &)>(41, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'hasFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QString &, const QString &)>(42, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'isEnabled'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>()>(43, 2, QMC::AccessPublic, 0x80000000 | 29),
        // Slot 'isOpen'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int)>(44, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'isOpen'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &)>(44, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'keyDoesNotExist'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(const QString &, const QString &, const QString &)>(45, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::QString, 4 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'localWallet'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(46, 2, QMC::AccessPublic, 0x80000000 | 47),
        // Slot 'mapList'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(int, const QString &, const QString &)>(48, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'networkWallet'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>()>(49, 2, QMC::AccessPublic, 0x80000000 | 47),
        // Slot 'open'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &, qlonglong, const QString &)>(50, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 4 }, { QMetaType::LongLong, 22 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'openAsync'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &, qlonglong, const QString &, bool)>(51, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 4 }, { QMetaType::LongLong, 22 }, { QMetaType::QString, 23 }, { QMetaType::Bool, 52 },
        }}),
        // Slot 'openPath'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &, qlonglong, const QString &)>(53, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 54 }, { QMetaType::LongLong, 22 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'openPathAsync'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(const QString &, qlonglong, const QString &, bool)>(55, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::QString, 54 }, { QMetaType::LongLong, 22 }, { QMetaType::QString, 23 }, { QMetaType::Bool, 52 },
        }}),
        // Slot 'pamOpen'
        QtMocHelpers::SlotData<void(const QString &, const QByteArray &, int)>(56, 57, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::QByteArray, 58 }, { QMetaType::Int, 59 },
        }}),
        // Slot 'passwordList'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(int, const QString &, const QString &)>(60, 2, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'readEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<QByteArray>(int, const QString &, const QString &, const QString &)>(61, 2, QMC::AccessPublic, 0x80000000 | 62, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'readEntryList'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(int, const QString &, const QString &, const QString &)>(63, 14, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'readMap'
        QtMocHelpers::SlotData<QDBusPendingReply<QByteArray>(int, const QString &, const QString &, const QString &)>(64, 2, QMC::AccessPublic, 0x80000000 | 62, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'readMapList'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(int, const QString &, const QString &, const QString &)>(65, 14, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'readPassword'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(int, const QString &, const QString &, const QString &)>(66, 2, QMC::AccessPublic, 0x80000000 | 47, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'readPasswordList'
        QtMocHelpers::SlotData<QDBusPendingReply<QVariantMap>(int, const QString &, const QString &, const QString &)>(67, 14, QMC::AccessPublic, 0x80000000 | 34, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(68, 2, QMC::AccessPublic, 0x80000000 | 21),
        // Slot 'removeEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, const QString &, const QString &, const QString &)>(69, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'removeFolder'
        QtMocHelpers::SlotData<QDBusPendingReply<bool>(int, const QString &, const QString &)>(70, 2, QMC::AccessPublic, 0x80000000 | 29, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'renameEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, const QString &, const QString &, const QString &, const QString &)>(71, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 72 }, { QMetaType::QString, 73 },
            { QMetaType::QString, 23 },
        }}),
        // Slot 'sync'
        QtMocHelpers::SlotData<void(int, const QString &)>(74, 57, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'users'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>(const QString &)>(75, 2, QMC::AccessPublic, 0x80000000 | 36, {{
            { QMetaType::QString, 4 },
        }}),
        // Slot 'wallets'
        QtMocHelpers::SlotData<QDBusPendingReply<QStringList>()>(76, 2, QMC::AccessPublic, 0x80000000 | 36),
        // Slot 'writeEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, const QString &, const QString &, const QByteArray &, const QString &)>(77, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QByteArray, 78 },
            { QMetaType::QString, 23 },
        }}),
        // Slot 'writeEntry'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, const QString &, const QString &, const QByteArray &, int, const QString &)>(77, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QByteArray, 78 },
            { QMetaType::Int, 37 }, { QMetaType::QString, 23 },
        }}),
        // Slot 'writeMap'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, const QString &, const QString &, const QByteArray &, const QString &)>(79, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QByteArray, 78 },
            { QMetaType::QString, 23 },
        }}),
        // Slot 'writePassword'
        QtMocHelpers::SlotData<QDBusPendingReply<int>(int, const QString &, const QString &, const QString &, const QString &)>(80, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { QMetaType::Int, 12 }, { QMetaType::QString, 30 }, { QMetaType::QString, 38 }, { QMetaType::QString, 78 },
            { QMetaType::QString, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKWalletInterface, qt_meta_tag_ZN22OrgKdeKWalletInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKWalletInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22OrgKdeKWalletInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22OrgKdeKWalletInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22OrgKdeKWalletInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKWalletInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKWalletInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->allWalletsClosed(); break;
        case 1: _t->applicationDisconnected((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->folderListUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->folderUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->walletAsyncOpened((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->walletClosed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->walletClosed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->walletClosedId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->walletCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->walletDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->walletListDirty(); break;
        case 11: _t->walletOpened((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: { QDBusPendingReply<> _r = _t->changePassword((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 13: { QDBusPendingReply<int> _r = _t->close((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 14: { QDBusPendingReply<int> _r = _t->close((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 15: { QDBusPendingReply<> _r = _t->closeAllWallets();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 16: { QDBusPendingReply<bool> _r = _t->createFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 17: { QDBusPendingReply<int> _r = _t->deleteWallet((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 18: { QDBusPendingReply<bool> _r = _t->disconnectApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 19: { QDBusPendingReply<QVariantMap> _r = _t->entriesList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 20: { QDBusPendingReply<QStringList> _r = _t->entryList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 21: { QDBusPendingReply<int> _r = _t->entryType((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 22: { QDBusPendingReply<bool> _r = _t->folderDoesNotExist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 23: { QDBusPendingReply<QStringList> _r = _t->folderList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 24: { QDBusPendingReply<bool> _r = _t->hasEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 25: { QDBusPendingReply<bool> _r = _t->hasFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 26: { QDBusPendingReply<bool> _r = _t->isEnabled();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 27: { QDBusPendingReply<bool> _r = _t->isOpen((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 28: { QDBusPendingReply<bool> _r = _t->isOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 29: { QDBusPendingReply<bool> _r = _t->keyDoesNotExist((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 30: { QDBusPendingReply<QString> _r = _t->localWallet();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 31: { QDBusPendingReply<QVariantMap> _r = _t->mapList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 32: { QDBusPendingReply<QString> _r = _t->networkWallet();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 33: { QDBusPendingReply<int> _r = _t->open((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 34: { QDBusPendingReply<int> _r = _t->openAsync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 35: { QDBusPendingReply<int> _r = _t->openPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 36: { QDBusPendingReply<int> _r = _t->openPathAsync((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 37: _t->pamOpen((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 38: { QDBusPendingReply<QVariantMap> _r = _t->passwordList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 39: { QDBusPendingReply<QByteArray> _r = _t->readEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QByteArray>*>(_a[0]) = std::move(_r); }  break;
        case 40: { QDBusPendingReply<QVariantMap> _r = _t->readEntryList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 41: { QDBusPendingReply<QByteArray> _r = _t->readMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QByteArray>*>(_a[0]) = std::move(_r); }  break;
        case 42: { QDBusPendingReply<QVariantMap> _r = _t->readMapList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 43: { QDBusPendingReply<QString> _r = _t->readPassword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 44: { QDBusPendingReply<QVariantMap> _r = _t->readPasswordList((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QVariantMap>*>(_a[0]) = std::move(_r); }  break;
        case 45: { QDBusPendingReply<> _r = _t->reconfigure();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 46: { QDBusPendingReply<int> _r = _t->removeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 47: { QDBusPendingReply<bool> _r = _t->removeFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<bool>*>(_a[0]) = std::move(_r); }  break;
        case 48: { QDBusPendingReply<int> _r = _t->renameEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 49: _t->sync((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 50: { QDBusPendingReply<QStringList> _r = _t->users((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 51: { QDBusPendingReply<QStringList> _r = _t->wallets();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QStringList>*>(_a[0]) = std::move(_r); }  break;
        case 52: { QDBusPendingReply<int> _r = _t->writeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 53: { QDBusPendingReply<int> _r = _t->writeEntry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 54: { QDBusPendingReply<int> _r = _t->writeMap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QByteArray>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        case 55: { QDBusPendingReply<int> _r = _t->writePassword((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<int>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)()>(_a, &OrgKdeKWalletInterface::allWalletsClosed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(const QString & , const QString & )>(_a, &OrgKdeKWalletInterface::applicationDisconnected, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(const QString & )>(_a, &OrgKdeKWalletInterface::folderListUpdated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(const QString & , const QString & )>(_a, &OrgKdeKWalletInterface::folderUpdated, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(int , int )>(_a, &OrgKdeKWalletInterface::walletAsyncOpened, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(int )>(_a, &OrgKdeKWalletInterface::walletClosed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(const QString & )>(_a, &OrgKdeKWalletInterface::walletClosed, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(int )>(_a, &OrgKdeKWalletInterface::walletClosedId, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(const QString & )>(_a, &OrgKdeKWalletInterface::walletCreated, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(const QString & )>(_a, &OrgKdeKWalletInterface::walletDeleted, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)()>(_a, &OrgKdeKWalletInterface::walletListDirty, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKWalletInterface::*)(const QString & )>(_a, &OrgKdeKWalletInterface::walletOpened, 11))
            return;
    }
}

const QMetaObject *OrgKdeKWalletInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKWalletInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22OrgKdeKWalletInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKWalletInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 56)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 56;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 56)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 56;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKWalletInterface::allWalletsClosed()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void OrgKdeKWalletInterface::applicationDisconnected(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void OrgKdeKWalletInterface::folderListUpdated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgKdeKWalletInterface::folderUpdated(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void OrgKdeKWalletInterface::walletAsyncOpened(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void OrgKdeKWalletInterface::walletClosed(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void OrgKdeKWalletInterface::walletClosed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void OrgKdeKWalletInterface::walletClosedId(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void OrgKdeKWalletInterface::walletCreated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void OrgKdeKWalletInterface::walletDeleted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void OrgKdeKWalletInterface::walletListDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void OrgKdeKWalletInterface::walletOpened(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
