/********************************************************************************
** Form generated from reading UI file 'kwalletwizardpageintro.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KWALLETWIZARDPAGEINTRO_H
#define UI_KWALLETWIZARDPAGEINTRO_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktitlewidget.h"

QT_BEGIN_NAMESPACE

class Ui_KWalletWizardPageIntro
{
public:
    QVBoxLayout *verticalLayout;
    KTitleWidget *ktitlewidget;
    QLabel *textLabel2;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QVBoxLayout *vboxLayout;
    QRadioButton *_basic;
    QRadioButton *_advanced;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *KWalletWizardPageIntro)
    {
        if (KWalletWizardPageIntro->objectName().isEmpty())
            KWalletWizardPageIntro->setObjectName("KWalletWizardPageIntro");
        KWalletWizardPageIntro->resize(449, 327);
        verticalLayout = new QVBoxLayout(KWalletWizardPageIntro);
        verticalLayout->setObjectName("verticalLayout");
        ktitlewidget = new KTitleWidget(KWalletWizardPageIntro);
        ktitlewidget->setObjectName("ktitlewidget");

        verticalLayout->addWidget(ktitlewidget);

        textLabel2 = new QLabel(KWalletWizardPageIntro);
        textLabel2->setObjectName("textLabel2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(textLabel2->sizePolicy().hasHeightForWidth());
        textLabel2->setSizePolicy(sizePolicy);
        textLabel2->setTextFormat(Qt::RichText);
        textLabel2->setAlignment(Qt::AlignVCenter);
        textLabel2->setWordWrap(true);
        textLabel2->setMargin(12);

        verticalLayout->addWidget(textLabel2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        vboxLayout = new QVBoxLayout();
        vboxLayout->setObjectName("vboxLayout");
        _basic = new QRadioButton(KWalletWizardPageIntro);
        _basic->setObjectName("_basic");
        _basic->setChecked(true);

        vboxLayout->addWidget(_basic);

        _advanced = new QRadioButton(KWalletWizardPageIntro);
        _advanced->setObjectName("_advanced");

        vboxLayout->addWidget(_advanced);


        horizontalLayout->addLayout(vboxLayout);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);

        spacerItem = new QSpacerItem(21, 21, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(spacerItem);


        retranslateUi(KWalletWizardPageIntro);

        QMetaObject::connectSlotsByName(KWalletWizardPageIntro);
    } // setupUi

    void retranslateUi(QWidget *KWalletWizardPageIntro)
    {
        ktitlewidget->setComment(tr2i18n("The KDE Wallet System", nullptr));
        textLabel2->setText(tr2i18n("Welcome to KWallet, the KDE Wallet System.  KWallet allows you to store your passwords and other personal information on disk in an encrypted file, preventing others from viewing the information.  This wizard will tell you about KWallet and help you configure it for the first time.", nullptr));
        _basic->setText(tr2i18n("&Basic setup (recommended)", nullptr));
        _advanced->setText(tr2i18n("&Advanced setup", nullptr));
        (void)KWalletWizardPageIntro;
    } // retranslateUi

};

namespace Ui {
    class KWalletWizardPageIntro: public Ui_KWalletWizardPageIntro {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KWALLETWIZARDPAGEINTRO_H

