/****************************************************************************
** Meta object code from reading C++ file 'kwalletfreedesktopserviceadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "kwalletfreedesktopserviceadaptor.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletfreedesktopserviceadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN32KWalletFreedesktopServiceAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletFreedesktopServiceAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN32KWalletFreedesktopServiceAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletFreedesktopServiceAdaptor",
        "D-Bus Interface",
        "org.freedesktop.Secret.Service",
        "D-Bus Introspection",
        "  <interface name=\"org.freedesktop.Secret.Service\">\n    <proper"
        "ty access=\"read\" type=\"ao\" name=\"Collections\"/>\n    <method"
        " name=\"OpenSession\">\n      <arg direction=\"in\" type=\"s\" nam"
        "e=\"algorithm\"/>\n      <arg direction=\"in\" type=\"v\" name=\"i"
        "nput\"/>\n      <arg direction=\"out\" type=\"v\" name=\"output\"/"
        ">\n      <arg direction=\"out\" type=\"o\" name=\"result\"/>\n    "
        "</method>\n    <method name=\"CreateCollection\">\n      <arg dire"
        "ction=\"in\" type=\"a{sv}\" name=\"properties\"/>\n      <annotati"
        "on value=\"QVariantMap\" name=\"org.qtproject.QtDBus.QtTypeName.In"
        "0\"/>\n      <arg direction=\"in\" type=\"s\" name=\"alias\"/>\n  "
        "    <arg direction=\"out\" type=\"o\" name=\"collection\"/>\n     "
        " <arg direction=\"out\" type=\"o\" name=\"prompt\"/>\n    </method"
        ">\n    <method name=\"SearchItems\">\n      <arg direction=\"in\" "
        "type=\"a{ss}\" name=\"attributes\"/>\n      <annotation value=\"St"
        "rStrMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n      <a"
        "rg direction=\"out\" type=\"ao\" name=\"unlocked\"/>\n      <arg d"
        "irection=\"out\" type=\"ao\" name=\"locked\"/>\n    </method>\n   "
        " <method name=\"Unlock\">\n      <arg direction=\"in\" type=\"ao\""
        " name=\"objects\"/>\n      <arg direction=\"out\" type=\"ao\" name"
        "=\"unlocked\"/>\n      <arg direction=\"out\" type=\"o\" name=\"pr"
        "ompt\"/>\n    </method>\n    <method name=\"Lock\">\n      <arg di"
        "rection=\"in\" type=\"ao\" name=\"objects\"/>\n      <arg directio"
        "n=\"out\" type=\"ao\" name=\"locked\"/>\n      <arg direction=\"ou"
        "t\" type=\"o\" name=\"Prompt\"/>\n    </method>\n    <method name="
        "\"GetSecrets\">\n      <arg direction=\"in\" type=\"ao\" name=\"it"
        "ems\"/>\n      <arg direction=\"in\" type=\"o\" name=\"session\"/>"
        "\n      <arg direction=\"out\" type=\"a{o(oayays)}\" name=\"secret"
        "s\"/>\n      <annotation value=\"FreedesktopSecretMap\" name=\"org"
        ".qtproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <method "
        "name=\"ReadAlias\">\n      <arg direction=\"in\" type=\"s\" name=\""
        "name\"/>\n      <arg direction=\"out\" type=\"o\" name=\"collectio"
        "n\"/>\n    </method>\n    <method name=\"SetAlias\">\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"name\"/>\n      <arg direction=\""
        "in\" type=\"o\" name=\"collection\"/>\n    </method>\n    <signal "
        "name=\"CollectionCreated\">\n      <arg type=\"o\" name=\"collecti"
        "on\"/>\n    </signal>\n    <signal name=\"CollectionDeleted\">\n  "
        "    <arg type=\"o\" name=\"collection\"/>\n    </signal>\n    <sig"
        "nal name=\"CollectionChanged\">\n      <arg type=\"o\" name=\"coll"
        "ection\"/>\n    </signal>\n  </interface>\n",
        "CollectionChanged",
        "",
        "QDBusObjectPath",
        "collection",
        "CollectionCreated",
        "CollectionDeleted",
        "CreateCollection",
        "QVariantMap",
        "properties",
        "alias",
        "QDBusObjectPath&",
        "prompt",
        "GetSecrets",
        "FreedesktopSecretMap",
        "QList<QDBusObjectPath>",
        "items",
        "session",
        "Lock",
        "objects",
        "Prompt",
        "OpenSession",
        "QDBusVariant",
        "algorithm",
        "input",
        "result",
        "ReadAlias",
        "name",
        "SearchItems",
        "StrStrMap",
        "attributes",
        "QList<QDBusObjectPath>&",
        "locked",
        "SetAlias",
        "Unlock",
        "Collections"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'CollectionChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'CollectionCreated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'CollectionDeleted'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'CreateCollection'
        QtMocHelpers::SlotData<QDBusObjectPath(const QVariantMap &, const QString &, QDBusObjectPath &)>(11, 6, QMC::AccessPublic, 0x80000000 | 7, {{
            { 0x80000000 | 12, 13 }, { QMetaType::QString, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Slot 'GetSecrets'
        QtMocHelpers::SlotData<FreedesktopSecretMap(const QList<QDBusObjectPath> &, const QDBusObjectPath &)>(17, 6, QMC::AccessPublic, 0x80000000 | 18, {{
            { 0x80000000 | 19, 20 }, { 0x80000000 | 7, 21 },
        }}),
        // Slot 'Lock'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>(const QList<QDBusObjectPath> &, QDBusObjectPath &)>(22, 6, QMC::AccessPublic, 0x80000000 | 19, {{
            { 0x80000000 | 19, 23 }, { 0x80000000 | 15, 24 },
        }}),
        // Slot 'OpenSession'
        QtMocHelpers::SlotData<QDBusVariant(const QString &, const QDBusVariant &, QDBusObjectPath &)>(25, 6, QMC::AccessPublic, 0x80000000 | 26, {{
            { QMetaType::QString, 27 }, { 0x80000000 | 26, 28 }, { 0x80000000 | 15, 29 },
        }}),
        // Slot 'ReadAlias'
        QtMocHelpers::SlotData<QDBusObjectPath(const QString &)>(30, 6, QMC::AccessPublic, 0x80000000 | 7, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'SearchItems'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>(StrStrMap, QList<QDBusObjectPath> &)>(32, 6, QMC::AccessPublic, 0x80000000 | 19, {{
            { 0x80000000 | 33, 34 }, { 0x80000000 | 35, 36 },
        }}),
        // Slot 'SetAlias'
        QtMocHelpers::SlotData<void(const QString &, const QDBusObjectPath &)>(37, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 }, { 0x80000000 | 7, 8 },
        }}),
        // Slot 'Unlock'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>(const QList<QDBusObjectPath> &, QDBusObjectPath &)>(38, 6, QMC::AccessPublic, 0x80000000 | 19, {{
            { 0x80000000 | 19, 23 }, { 0x80000000 | 15, 16 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Collections'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(39, 0x80000000 | 19, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KWalletFreedesktopServiceAdaptor, qt_meta_tag_ZN32KWalletFreedesktopServiceAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KWalletFreedesktopServiceAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32KWalletFreedesktopServiceAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32KWalletFreedesktopServiceAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32KWalletFreedesktopServiceAdaptorE_t>.metaTypes,
    nullptr
} };

void KWalletFreedesktopServiceAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletFreedesktopServiceAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->CollectionChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 1: _t->CollectionCreated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: _t->CollectionDeleted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 3: { QDBusObjectPath _r = _t->CreateCollection((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 4: { FreedesktopSecretMap _r = _t->GetSecrets((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2])));
            if (_a[0]) *reinterpret_cast<FreedesktopSecretMap*>(_a[0]) = std::move(_r); }  break;
        case 5: { QList<QDBusObjectPath> _r = _t->Lock((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusVariant _r = _t->OpenSession((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusVariant*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusObjectPath _r = _t->ReadAlias((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 8: { QList<QDBusObjectPath> _r = _t->SearchItems((*reinterpret_cast<std::add_pointer_t<StrStrMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        case 9: _t->SetAlias((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[2]))); break;
        case 10: { QList<QDBusObjectPath> _r = _t->Unlock((*reinterpret_cast<std::add_pointer_t<QList<QDBusObjectPath>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StrStrMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopServiceAdaptor::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopServiceAdaptor::CollectionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopServiceAdaptor::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopServiceAdaptor::CollectionCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopServiceAdaptor::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopServiceAdaptor::CollectionDeleted, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->collections(); break;
        default: break;
        }
    }
}

const QMetaObject *KWalletFreedesktopServiceAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletFreedesktopServiceAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32KWalletFreedesktopServiceAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KWalletFreedesktopServiceAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void KWalletFreedesktopServiceAdaptor::CollectionChanged(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KWalletFreedesktopServiceAdaptor::CollectionCreated(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KWalletFreedesktopServiceAdaptor::CollectionDeleted(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
