/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Secrets.Collection.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef KWALLETFREEDESKTOPCOLLECTIONADAPTOR_H
#define KWALLETFREEDESKTOPCOLLECTIONADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "kwalletfreedesktopcollection.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.freedesktop.Secret.Collection
 */
class KWalletFreedesktopCollectionAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.freedesktop.Secret.Collection")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.freedesktop.Secret.Collection\">\n"
"    <property access=\"read\" type=\"ao\" name=\"Items\"/>\n"
"    <property access=\"readwrite\" type=\"s\" name=\"Label\"/>\n"
"    <property access=\"read\" type=\"b\" name=\"Locked\"/>\n"
"    <property access=\"read\" type=\"t\" name=\"Created\"/>\n"
"    <property access=\"read\" type=\"t\" name=\"Modified\"/>\n"
"    <method name=\"Delete\">\n"
"      <arg direction=\"out\" type=\"o\" name=\"prompt\"/>\n"
"    </method>\n"
"    <method name=\"SearchItems\">\n"
"      <arg direction=\"in\" type=\"a{ss}\" name=\"attributes\"/>\n"
"      <annotation value=\"StrStrMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"out\" type=\"ao\" name=\"results\"/>\n"
"    </method>\n"
"    <method name=\"CreateItem\">\n"
"      <arg direction=\"in\" type=\"a{sv}\" name=\"properties\"/>\n"
"      <annotation value=\"PropertiesMap\" name=\"org.qtproject.QtDBus.QtTypeName.In0\"/>\n"
"      <arg direction=\"in\" type=\"(oayays)\" name=\"secret\"/>\n"
"      <annotation value=\"FreedesktopSecret\" name=\"org.qtproject.QtDBus.QtTypeName.In1\"/>\n"
"      <arg direction=\"in\" type=\"b\" name=\"replace\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"item\"/>\n"
"      <arg direction=\"out\" type=\"o\" name=\"prompt\"/>\n"
"    </method>\n"
"    <signal name=\"ItemCreated\">\n"
"      <arg type=\"o\" name=\"item\"/>\n"
"    </signal>\n"
"    <signal name=\"ItemDeleted\">\n"
"      <arg type=\"o\" name=\"item\"/>\n"
"    </signal>\n"
"    <signal name=\"ItemChanged\">\n"
"      <arg type=\"o\" name=\"item\"/>\n"
"    </signal>\n"
"  </interface>\n"
        "")
public:
    KWalletFreedesktopCollectionAdaptor(KWalletFreedesktopCollection *parent);
    ~KWalletFreedesktopCollectionAdaptor() override;

    inline KWalletFreedesktopCollection *parent() const
    { return static_cast<KWalletFreedesktopCollection *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(qulonglong Created READ created)
    qulonglong created() const;

    Q_PROPERTY(QList<QDBusObjectPath> Items READ items)
    QList<QDBusObjectPath> items() const;

    Q_PROPERTY(QString Label READ label WRITE setLabel)
    QString label() const;
    void setLabel(const QString &value);

    Q_PROPERTY(bool Locked READ locked)
    bool locked() const;

    Q_PROPERTY(qulonglong Modified READ modified)
    qulonglong modified() const;

public Q_SLOTS: // METHODS
    QDBusObjectPath CreateItem(PropertiesMap properties, FreedesktopSecret secret, bool replace, QDBusObjectPath &prompt);
    QDBusObjectPath Delete();
    QList<QDBusObjectPath> SearchItems(StrStrMap attributes);
Q_SIGNALS: // SIGNALS
    void ItemChanged(const QDBusObjectPath &item);
    void ItemCreated(const QDBusObjectPath &item);
    void ItemDeleted(const QDBusObjectPath &item);
};

#endif
