/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.impl.portal.Secret.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kwalletportalsecretsadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KWalletPortalSecretsAdaptor
 */

KWalletPortalSecretsAdaptor::KWalletPortalSecretsAdaptor(KWalletPortalSecrets *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KWalletPortalSecretsAdaptor::~KWalletPortalSecretsAdaptor()
{
    // destructor
}

uint KWalletPortalSecretsAdaptor::version() const
{
    // get the value of property version
    return qvariant_cast< uint >(parent()->property("version"));
}

uint KWalletPortalSecretsAdaptor::RetrieveSecret(const QDBusObjectPath &handle, const QString &app_id, const QDBusUnixFileDescriptor &fd, const QVariantMap &options, QVariantMap &results)
{
    // handle method call org.freedesktop.impl.portal.Secret.RetrieveSecret
    return parent()->RetrieveSecret(handle, app_id, fd, options, results);
}


#include "moc_kwalletportalsecretsadaptor.cpp"
