/********************************************************************************
** Form generated from reading UI file 'kwalletwizardpageoptions.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KWALLETWIZARDPAGEOPTIONS_H
#define UI_KWALLETWIZARDPAGEOPTIONS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KWalletWizardPageOptions
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *textLabel1_3;
    QSpacerItem *spacerItem;
    QCheckBox *_closeIdle;
    QCheckBox *_networkWallet;
    QSpacerItem *spacerItem1;

    void setupUi(QWidget *KWalletWizardPageOptions)
    {
        if (KWalletWizardPageOptions->objectName().isEmpty())
            KWalletWizardPageOptions->setObjectName("KWalletWizardPageOptions");
        KWalletWizardPageOptions->resize(436, 214);
        vboxLayout = new QVBoxLayout(KWalletWizardPageOptions);
        vboxLayout->setObjectName("vboxLayout");
        textLabel1_3 = new QLabel(KWalletWizardPageOptions);
        textLabel1_3->setObjectName("textLabel1_3");
        textLabel1_3->setTextFormat(Qt::RichText);
        textLabel1_3->setAlignment(Qt::AlignVCenter);
        textLabel1_3->setWordWrap(true);

        vboxLayout->addWidget(textLabel1_3);

        spacerItem = new QSpacerItem(21, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        vboxLayout->addItem(spacerItem);

        _closeIdle = new QCheckBox(KWalletWizardPageOptions);
        _closeIdle->setObjectName("_closeIdle");

        vboxLayout->addWidget(_closeIdle);

        _networkWallet = new QCheckBox(KWalletWizardPageOptions);
        _networkWallet->setObjectName("_networkWallet");

        vboxLayout->addWidget(_networkWallet);

        spacerItem1 = new QSpacerItem(21, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::MinimumExpanding);

        vboxLayout->addItem(spacerItem1);


        retranslateUi(KWalletWizardPageOptions);

        QMetaObject::connectSlotsByName(KWalletWizardPageOptions);
    } // setupUi

    void retranslateUi(QWidget *KWalletWizardPageOptions)
    {
        textLabel1_3->setText(tr2i18n("The KDE Wallet system allows you to control the level of security of your personal data.  Some of these settings do impact usability.  While the default settings are generally acceptable for most users, you may wish to change some of them.  You may further tune these settings from the KWallet control module.", nullptr));
        _closeIdle->setText(tr2i18n("Automatically close idle wallets", nullptr));
        _networkWallet->setText(tr2i18n("Store network passwords and local passwords in separate wallet files", nullptr));
        (void)KWalletWizardPageOptions;
    } // retranslateUi

};

namespace Ui {
    class KWalletWizardPageOptions: public Ui_KWalletWizardPageOptions {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KWALLETWIZARDPAGEOPTIONS_H

