/****************************************************************************
** Meta object code from reading C++ file 'kwalletfreedesktopcollection.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kwallet-6.25.0/src/runtime/ksecretd/kwalletfreedesktopcollection.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kwalletfreedesktopcollection.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN28KWalletFreedesktopCollectionE_t {};
} // unnamed namespace

template <> constexpr inline auto KWalletFreedesktopCollection::qt_create_metaobjectdata<qt_meta_tag_ZN28KWalletFreedesktopCollectionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KWalletFreedesktopCollection",
        "ItemChanged",
        "",
        "QDBusObjectPath",
        "item",
        "ItemCreated",
        "ItemDeleted",
        "CreateItem",
        "PropertiesMap",
        "properties",
        "FreedesktopSecret",
        "secret",
        "replace",
        "QDBusObjectPath&",
        "prompt",
        "Delete",
        "SearchItems",
        "QList<QDBusObjectPath>",
        "StrStrMap",
        "attributes",
        "Created",
        "Modified",
        "Items",
        "Label",
        "Locked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ItemChanged'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'ItemCreated'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'ItemDeleted'
        QtMocHelpers::SignalData<void(const QDBusObjectPath &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'CreateItem'
        QtMocHelpers::SlotData<QDBusObjectPath(const PropertiesMap &, const FreedesktopSecret &, bool, QDBusObjectPath &)>(7, 2, QMC::AccessPublic, 0x80000000 | 3, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 10, 11 }, { QMetaType::Bool, 12 }, { 0x80000000 | 13, 14 },
        }}),
        // Slot 'Delete'
        QtMocHelpers::SlotData<QDBusObjectPath()>(15, 2, QMC::AccessPublic, 0x80000000 | 3),
        // Slot 'SearchItems'
        QtMocHelpers::SlotData<QList<QDBusObjectPath>(const StrStrMap &)>(16, 2, QMC::AccessPublic, 0x80000000 | 17, {{
            { 0x80000000 | 18, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'Created'
        QtMocHelpers::PropertyData<qulonglong>(20, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Modified'
        QtMocHelpers::PropertyData<qulonglong>(21, QMetaType::ULongLong, QMC::DefaultPropertyFlags),
        // property 'Items'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(22, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'Label'
        QtMocHelpers::PropertyData<QString>(23, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KWalletFreedesktopCollection, qt_meta_tag_ZN28KWalletFreedesktopCollectionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KWalletFreedesktopCollection::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28KWalletFreedesktopCollectionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28KWalletFreedesktopCollectionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN28KWalletFreedesktopCollectionE_t>.metaTypes,
    nullptr
} };

void KWalletFreedesktopCollection::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KWalletFreedesktopCollection *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ItemChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 1: _t->ItemCreated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 2: _t->ItemDeleted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 3: { QDBusObjectPath _r = _t->CreateItem((*reinterpret_cast<std::add_pointer_t<PropertiesMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<FreedesktopSecret>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusObjectPath _r = _t->Delete();
            if (_a[0]) *reinterpret_cast<QDBusObjectPath*>(_a[0]) = std::move(_r); }  break;
        case 5: { QList<QDBusObjectPath> _r = _t->SearchItems((*reinterpret_cast<std::add_pointer_t<StrStrMap>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QList<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< FreedesktopSecret >(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PropertiesMap >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< StrStrMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopCollection::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopCollection::ItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopCollection::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopCollection::ItemCreated, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KWalletFreedesktopCollection::*)(const QDBusObjectPath & )>(_a, &KWalletFreedesktopCollection::ItemDeleted, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<QDBusObjectPath> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<qulonglong*>(_v) = _t->created(); break;
        case 1: *reinterpret_cast<qulonglong*>(_v) = _t->modified(); break;
        case 2: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->items(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->label(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setLabel(*reinterpret_cast<QString*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KWalletFreedesktopCollection::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KWalletFreedesktopCollection::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN28KWalletFreedesktopCollectionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int KWalletFreedesktopCollection::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void KWalletFreedesktopCollection::ItemChanged(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KWalletFreedesktopCollection::ItemCreated(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KWalletFreedesktopCollection::ItemDeleted(const QDBusObjectPath & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
