/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.freedesktop.Secrets.Prompt.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kwalletfreedesktoppromptadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KWalletFreedesktopPromptAdaptor
 */

KWalletFreedesktopPromptAdaptor::KWalletFreedesktopPromptAdaptor(KWalletFreedesktopPrompt *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KWalletFreedesktopPromptAdaptor::~KWalletFreedesktopPromptAdaptor()
{
    // destructor
}

void KWalletFreedesktopPromptAdaptor::Dismiss()
{
    // handle method call org.freedesktop.Secret.Prompt.Dismiss
    parent()->Dismiss();
}

void KWalletFreedesktopPromptAdaptor::Prompt(const QString &window_id)
{
    // handle method call org.freedesktop.Secret.Prompt.Prompt
    parent()->Prompt(window_id);
}


#include "moc_kwalletfreedesktoppromptadaptor.cpp"
