/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.kde.KWallet.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "kwalletadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class KWalletAdaptor
 */

KWalletAdaptor::KWalletAdaptor(KSecretD *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

KWalletAdaptor::~KWalletAdaptor()
{
    // destructor
}

void KWalletAdaptor::changePassword(const QString &wallet, qlonglong wId, const QString &appid)
{
    // handle method call org.kde.KWallet.changePassword
    parent()->changePassword(wallet, wId, appid);
}

int KWalletAdaptor::close(int handle, bool force, const QString &appid)
{
    // handle method call org.kde.KWallet.close
    return parent()->close(handle, force, appid);
}

int KWalletAdaptor::close(const QString &wallet, bool force)
{
    // handle method call org.kde.KWallet.close
    return parent()->close(wallet, force);
}

void KWalletAdaptor::closeAllWallets()
{
    // handle method call org.kde.KWallet.closeAllWallets
    parent()->closeAllWallets();
}

bool KWalletAdaptor::createFolder(int handle, const QString &folder, const QString &appid)
{
    // handle method call org.kde.KWallet.createFolder
    return parent()->createFolder(handle, folder, appid);
}

int KWalletAdaptor::deleteWallet(const QString &wallet)
{
    // handle method call org.kde.KWallet.deleteWallet
    return parent()->deleteWallet(wallet);
}

bool KWalletAdaptor::disconnectApplication(const QString &wallet, const QString &application)
{
    // handle method call org.kde.KWallet.disconnectApplication
    return parent()->disconnectApplication(wallet, application);
}

QVariantMap KWalletAdaptor::entriesList(int handle, const QString &folder, const QString &appid)
{
    // handle method call org.kde.KWallet.entriesList
    return parent()->entriesList(handle, folder, appid);
}

QStringList KWalletAdaptor::entryList(int handle, const QString &folder, const QString &appid)
{
    // handle method call org.kde.KWallet.entryList
    return parent()->entryList(handle, folder, appid);
}

int KWalletAdaptor::entryType(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.entryType
    return parent()->entryType(handle, folder, key, appid);
}

bool KWalletAdaptor::folderDoesNotExist(const QString &wallet, const QString &folder)
{
    // handle method call org.kde.KWallet.folderDoesNotExist
    return parent()->folderDoesNotExist(wallet, folder);
}

QStringList KWalletAdaptor::folderList(int handle, const QString &appid)
{
    // handle method call org.kde.KWallet.folderList
    return parent()->folderList(handle, appid);
}

bool KWalletAdaptor::hasEntry(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.hasEntry
    return parent()->hasEntry(handle, folder, key, appid);
}

bool KWalletAdaptor::hasFolder(int handle, const QString &folder, const QString &appid)
{
    // handle method call org.kde.KWallet.hasFolder
    return parent()->hasFolder(handle, folder, appid);
}

bool KWalletAdaptor::isEnabled()
{
    // handle method call org.kde.KWallet.isEnabled
    return parent()->isEnabled();
}

bool KWalletAdaptor::isOpen(int handle)
{
    // handle method call org.kde.KWallet.isOpen
    return parent()->isOpen(handle);
}

bool KWalletAdaptor::isOpen(const QString &wallet)
{
    // handle method call org.kde.KWallet.isOpen
    return parent()->isOpen(wallet);
}

bool KWalletAdaptor::keyDoesNotExist(const QString &wallet, const QString &folder, const QString &key)
{
    // handle method call org.kde.KWallet.keyDoesNotExist
    return parent()->keyDoesNotExist(wallet, folder, key);
}

QString KWalletAdaptor::localWallet()
{
    // handle method call org.kde.KWallet.localWallet
    return parent()->localWallet();
}

QVariantMap KWalletAdaptor::mapList(int handle, const QString &folder, const QString &appid)
{
    // handle method call org.kde.KWallet.mapList
    return parent()->mapList(handle, folder, appid);
}

QString KWalletAdaptor::networkWallet()
{
    // handle method call org.kde.KWallet.networkWallet
    return parent()->networkWallet();
}

int KWalletAdaptor::open(const QString &wallet, qlonglong wId, const QString &appid)
{
    // handle method call org.kde.KWallet.open
    return parent()->open(wallet, wId, appid);
}

int KWalletAdaptor::openAsync(const QString &wallet, qlonglong wId, const QString &appid, bool handleSession)
{
    // handle method call org.kde.KWallet.openAsync
    return parent()->openAsync(wallet, wId, appid, handleSession);
}

int KWalletAdaptor::openPath(const QString &path, qlonglong wId, const QString &appid)
{
    // handle method call org.kde.KWallet.openPath
    return parent()->openPath(path, wId, appid);
}

int KWalletAdaptor::openPathAsync(const QString &path, qlonglong wId, const QString &appid, bool handleSession)
{
    // handle method call org.kde.KWallet.openPathAsync
    return parent()->openPathAsync(path, wId, appid, handleSession);
}

void KWalletAdaptor::pamOpen(const QString &wallet, const QByteArray &passwordHash, int sessionTimeout)
{
    // handle method call org.kde.KWallet.pamOpen
    parent()->pamOpen(wallet, passwordHash, sessionTimeout);
}

QVariantMap KWalletAdaptor::passwordList(int handle, const QString &folder, const QString &appid)
{
    // handle method call org.kde.KWallet.passwordList
    return parent()->passwordList(handle, folder, appid);
}

QByteArray KWalletAdaptor::readEntry(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.readEntry
    return parent()->readEntry(handle, folder, key, appid);
}

QVariantMap KWalletAdaptor::readEntryList(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.readEntryList
    return parent()->readEntryList(handle, folder, key, appid);
}

QByteArray KWalletAdaptor::readMap(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.readMap
    return parent()->readMap(handle, folder, key, appid);
}

QVariantMap KWalletAdaptor::readMapList(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.readMapList
    return parent()->readMapList(handle, folder, key, appid);
}

QString KWalletAdaptor::readPassword(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.readPassword
    return parent()->readPassword(handle, folder, key, appid);
}

QVariantMap KWalletAdaptor::readPasswordList(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.readPasswordList
    return parent()->readPasswordList(handle, folder, key, appid);
}

void KWalletAdaptor::reconfigure()
{
    // handle method call org.kde.KWallet.reconfigure
    parent()->reconfigure();
}

int KWalletAdaptor::removeEntry(int handle, const QString &folder, const QString &key, const QString &appid)
{
    // handle method call org.kde.KWallet.removeEntry
    return parent()->removeEntry(handle, folder, key, appid);
}

bool KWalletAdaptor::removeFolder(int handle, const QString &folder, const QString &appid)
{
    // handle method call org.kde.KWallet.removeFolder
    return parent()->removeFolder(handle, folder, appid);
}

int KWalletAdaptor::renameEntry(int handle, const QString &folder, const QString &oldName, const QString &newName, const QString &appid)
{
    // handle method call org.kde.KWallet.renameEntry
    return parent()->renameEntry(handle, folder, oldName, newName, appid);
}

void KWalletAdaptor::sync(int handle, const QString &appid)
{
    // handle method call org.kde.KWallet.sync
    parent()->sync(handle, appid);
}

QStringList KWalletAdaptor::users(const QString &wallet)
{
    // handle method call org.kde.KWallet.users
    return parent()->users(wallet);
}

QStringList KWalletAdaptor::wallets()
{
    // handle method call org.kde.KWallet.wallets
    return parent()->wallets();
}

int KWalletAdaptor::writeEntry(int handle, const QString &folder, const QString &key, const QByteArray &value, const QString &appid)
{
    // handle method call org.kde.KWallet.writeEntry
    return parent()->writeEntry(handle, folder, key, value, appid);
}

int KWalletAdaptor::writeEntry(int handle, const QString &folder, const QString &key, const QByteArray &value, int entryType, const QString &appid)
{
    // handle method call org.kde.KWallet.writeEntry
    return parent()->writeEntry(handle, folder, key, value, entryType, appid);
}

int KWalletAdaptor::writeMap(int handle, const QString &folder, const QString &key, const QByteArray &value, const QString &appid)
{
    // handle method call org.kde.KWallet.writeMap
    return parent()->writeMap(handle, folder, key, value, appid);
}

int KWalletAdaptor::writePassword(int handle, const QString &folder, const QString &key, const QString &value, const QString &appid)
{
    // handle method call org.kde.KWallet.writePassword
    return parent()->writePassword(handle, folder, key, value, appid);
}


#include "moc_kwalletadaptor.cpp"
