/********************************************************************************
** Form generated from reading UI file 'kwalletwizardpageexplanation.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KWALLETWIZARDPAGEEXPLANATION_H
#define UI_KWALLETWIZARDPAGEEXPLANATION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KWalletWizardPageExplanation
{
public:
    QVBoxLayout *vboxLayout;
    QLabel *textLabel2_3;

    void setupUi(QWidget *KWalletWizardPageExplanation)
    {
        if (KWalletWizardPageExplanation->objectName().isEmpty())
            KWalletWizardPageExplanation->setObjectName("KWalletWizardPageExplanation");
        KWalletWizardPageExplanation->resize(478, 215);
        vboxLayout = new QVBoxLayout(KWalletWizardPageExplanation);
        vboxLayout->setObjectName("vboxLayout");
        textLabel2_3 = new QLabel(KWalletWizardPageExplanation);
        textLabel2_3->setObjectName("textLabel2_3");
        textLabel2_3->setTextFormat(Qt::RichText);
        textLabel2_3->setWordWrap(true);

        vboxLayout->addWidget(textLabel2_3);


        retranslateUi(KWalletWizardPageExplanation);

        QMetaObject::connectSlotsByName(KWalletWizardPageExplanation);
    } // setupUi

    void retranslateUi(QWidget *KWalletWizardPageExplanation)
    {
        textLabel2_3->setText(tr2i18n("<html><head/><body><p>The KDE Wallet system stores your data in a <span style=\" font-style:italic;\">wallet</span> file on your local hard disk. The data is only written in the encrypted form of your choice - blowfish algorithm with your password as the key or using a GPG encryption key. When a wallet is opened, the wallet manager application will launch and display an icon in the system tray. You can use this application to manage all of your wallets. It even permits you to drag wallets and wallet contents, allowing you to easily copy a wallet to a remote system.</p></body></html>", nullptr));
        (void)KWalletWizardPageExplanation;
    } // retranslateUi

};

namespace Ui {
    class KWalletWizardPageExplanation: public Ui_KWalletWizardPageExplanation {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KWALLETWIZARDPAGEEXPLANATION_H

