/****************************************************************************
** Meta object code from reading C++ file 'secretserviceclient.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../../../kwallet-6.25.0/src/runtime/kwalletd/secretserviceclient.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'secretserviceclient.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19SecretServiceClientE_t {};
} // unnamed namespace

template <> constexpr inline auto SecretServiceClient::qt_create_metaobjectdata<qt_meta_tag_ZN19SecretServiceClientE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SecretServiceClient",
        "serviceChanged",
        "",
        "promptClosed",
        "accepted",
        "collectionListDirty",
        "collectionDirty",
        "collection",
        "collectionCreated",
        "collectionDeleted",
        "handlePrompt",
        "dismissed",
        "onCollectionCreated",
        "QDBusObjectPath",
        "path",
        "onCollectionDeleted",
        "onSecretItemChanged",
        "Type",
        "PlainText",
        "Base64",
        "Binary",
        "Map",
        "Unknown"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'serviceChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'promptClosed'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'collectionListDirty'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collectionDirty'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'collectionCreated'
        QtMocHelpers::SignalData<void(const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'collectionDeleted'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'handlePrompt'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'onCollectionCreated'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(12, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'onCollectionDeleted'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(15, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'onSecretItemChanged'
        QtMocHelpers::SlotData<void(const QDBusObjectPath &)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Type'
        QtMocHelpers::EnumData<enum Type>(17, 17, QMC::EnumFlags{}).add({
            {   18, Type::PlainText },
            {   19, Type::Base64 },
            {   20, Type::Binary },
            {   21, Type::Map },
            {   22, Type::Unknown },
        }),
    };
    return QtMocHelpers::metaObjectData<SecretServiceClient, qt_meta_tag_ZN19SecretServiceClientE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SecretServiceClient::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SecretServiceClientE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SecretServiceClientE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19SecretServiceClientE_t>.metaTypes,
    nullptr
} };

void SecretServiceClient::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SecretServiceClient *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->serviceChanged(); break;
        case 1: _t->promptClosed((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->collectionListDirty(); break;
        case 3: _t->collectionDirty((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->collectionCreated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->collectionDeleted((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->handlePrompt((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->onCollectionCreated((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 8: _t->onCollectionDeleted((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        case 9: _t->onSecretItemChanged((*reinterpret_cast<std::add_pointer_t<QDBusObjectPath>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusObjectPath >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SecretServiceClient::*)()>(_a, &SecretServiceClient::serviceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecretServiceClient::*)(bool )>(_a, &SecretServiceClient::promptClosed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecretServiceClient::*)()>(_a, &SecretServiceClient::collectionListDirty, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecretServiceClient::*)(const QString & )>(_a, &SecretServiceClient::collectionDirty, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecretServiceClient::*)(const QString & )>(_a, &SecretServiceClient::collectionCreated, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SecretServiceClient::*)(const QString & )>(_a, &SecretServiceClient::collectionDeleted, 5))
            return;
    }
}

const QMetaObject *SecretServiceClient::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SecretServiceClient::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19SecretServiceClientE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SecretServiceClient::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void SecretServiceClient::serviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SecretServiceClient::promptClosed(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SecretServiceClient::collectionListDirty()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SecretServiceClient::collectionDirty(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void SecretServiceClient::collectionCreated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void SecretServiceClient::collectionDeleted(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
